@@ -17,7 +17,7 @@ TARGET="$(uname -m)"
 TARGET_CFLAGS=''
 QUIET='VERBOSE=1'
 WITH_JEMALLOC=''
-DEBUG_EXTRA=''
+DEBUG_EXTNAME=''
 WITH_SSL='/usr'
 WITH_SSL_TYPE='system'
 OPENSSL_INCLUDE=''
@@ -28,7 +28,7 @@ TAG=''
 CMAKE_BUILD_TYPE=''
 COMMON_FLAGS=''
 #
-TOKUDB_BACKUP_VERSION=''
+TOKUDB_BACKUP_VERSION='5.6.29-76.2'
 #
 # Some programs that may be overriden
 TAR=${TAR:-tar}
@@ -56,7 +56,7 @@ do
         shift
         CMAKE_BUILD_TYPE='Debug'
         BUILD_COMMENT="${BUILD_COMMENT:-}-debug"
-        DEBUG_EXTRA="-DDEBUG_EXTNAME=OFF"
+        DEBUG_EXTNAME='-DDEBUG_EXTNAME=OFF'
         ;;
     -v | --valgrind )
         shift
@@ -108,7 +108,7 @@ done
 if test "$#" -eq 0
 then
     WORKDIR="$(pwd)"
-
+    
     # Check that the current directory is not empty
     if test "x$(echo *)" != "x*"
     then
@@ -172,20 +172,11 @@ COMMENT="$COMMENT, Revision $REVISION${BUILD_COMMENT:-}"
 export CC=${CC:-gcc}
 export CXX=${CXX:-g++}
 
-# If gcc >= 4.8 we can use ASAN in debug build but not if valgrind build also
-if [[ "$CMAKE_BUILD_TYPE" == "Debug" ]] && [[ "${CMAKE_OPTS:-}" != *WITH_VALGRIND=ON* ]]; then
-  GCC_VERSION=$(${CC} -dumpversion)
-  GT_VERSION=$(echo -e "4.8.0\n${GCC_VERSION}" | sort -t. -k1,1nr -k2,2nr -k3,3nr | head -1)
-  if [ "${GT_VERSION}" = "${GCC_VERSION}" ]; then
-    DEBUG_EXTRA="${DEBUG_EXTRA} -DWITH_ASAN=ON"
-  fi
-fi
-
 # TokuDB cmake flags
 if test -d "$SOURCEDIR/storage/tokudb"
 then
     CMAKE_OPTS="${CMAKE_OPTS:-} -DBUILD_TESTING=OFF -DUSE_GTAGS=OFF -DUSE_CTAGS=OFF -DUSE_ETAGS=OFF -DUSE_CSCOPE=OFF -DTOKUDB_BACKUP_PLUGIN_VERSION=${TOKUDB_BACKUP_VERSION}"
-
+    
     if test "x$CMAKE_BUILD_TYPE" != "xDebug"
     then
         CMAKE_OPTS="${CMAKE_OPTS:-} -DTOKU_DEBUG_PARANOID=OFF"
@@ -233,7 +224,7 @@ then
         echo >&2 "Jemalloc dir $WITH_JEMALLOC does not exist"
         exit 1
     fi
-
+    
     JEMALLOCDIR="$(cd "$WITH_JEMALLOC"; pwd)"
 
 fi
@@ -241,10 +232,10 @@ fi
 # Build
 (
     cd "$SOURCEDIR"
-
+ 
     cmake . ${CMAKE_OPTS:-} -DBUILD_CONFIG=mysql_release \
         -DCMAKE_BUILD_TYPE=${CMAKE_BUILD_TYPE:-RelWithDebInfo} \
-        $DEBUG_EXTRA \
+        $DEBUG_EXTNAME \
         -DWITH_EMBEDDED_SERVER=OFF \
         -DFEATURE_SET=community \
         -DENABLE_DTRACE=OFF \
@@ -254,7 +245,6 @@ fi
         -DCOMPILATION_COMMENT="$COMMENT" \
         -DWITH_PAM=ON \
         -DWITH_INNODB_MEMCACHED=ON \
-           -DWITH_SCALABILITY_METRICS=ON \
         $OPENSSL_INCLUDE $OPENSSL_LIBRARY $CRYPTO_LIBRARY
 
     make $MAKE_JFLAG $QUIET
@@ -286,8 +276,7 @@ fi
 # Package the archive
 (
     cd "$INSTALLDIR/usr/local/"
-    #PS-4854 Percona Server for MySQL tarball without AGPLv3 dependency/license
-    find $PRODUCT_FULL -type f -name 'COPYING.AGPLv3' -delete
+
     $TAR --owner=0 --group=0 -czf "$WORKDIR_ABS/$PRODUCT_FULL.tar.gz" $PRODUCT_FULL
 )
 
