@@ -11,11 +11,9 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,  USA */
+   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */
 
-#ifndef MYSQL_SERVER
 #define MYSQL_SERVER
-#endif
 #include <sql_class.h>
 #include <table.h>
 #include <sql_show.h>
@@ -26,49 +24,9 @@
 
 
 ulong opt_query_response_time_range_base= QRT_DEFAULT_BASE;
-static my_bool opt_query_response_time_stats= FALSE;
+my_bool opt_query_response_time_stats= FALSE;
 static my_bool opt_query_response_time_flush= FALSE;
 
-class qrt_atomic_flag
-{
-  public:
-    explicit qrt_atomic_flag(bool initial_value):
-      value_(initial_value ? 1 : 0)
-    {
-      my_atomic_rwlock_init(&lock_);
-    }
-    ~qrt_atomic_flag()
-    {
-      my_atomic_rwlock_destroy(&lock_);
-    }
-    void set()
-    {
-      my_atomic_rwlock_wrlock(&lock_);
-      my_atomic_store32(&value_, 1);
-      my_atomic_rwlock_wrunlock(&lock_);
-    }
-    void clear()
-    {
-      my_atomic_rwlock_wrlock(&lock_);
-      my_atomic_store32(&value_, 0);
-      my_atomic_rwlock_wrunlock(&lock_);
-    }
-    bool is_set() const
-    {
-      my_atomic_rwlock_rdlock(&lock_);
-      int32 res= my_atomic_load32(const_cast<volatile int32*>(&value_));
-      my_atomic_rwlock_rdunlock(&lock_);
-      return res != 0;
-    }
-
-  private:
-    qrt_atomic_flag(const qrt_atomic_flag&);
-    qrt_atomic_flag& operator = (const qrt_atomic_flag&);
-
-    mutable my_atomic_rwlock_t lock_;
-    volatile int32 value_;
-};
-static qrt_atomic_flag qrt_vars_initialized(false);
 
 static void query_response_time_flush_update(
               MYSQL_THD thd __attribute__((unused)),
@@ -102,22 +60,6 @@ static MYSQL_THDVAR_ULONGLONG(exec_time_debug, PLUGIN_VAR_NOCMDOPT,
        NULL, NULL, 0, 0, LONG_TIMEOUT, 1);
 #endif
 
-enum session_stat
-{
-  session_stat_global,
-  session_stat_on,
-  session_stat_off
-};
-
-static const char *session_stat_names[]= {"GLOBAL", "ON", "OFF", NullS};
-static TYPELIB session_stat_typelib= { array_elements(session_stat_names) - 1,
-                                       "", session_stat_names, NULL};
-
-static MYSQL_THDVAR_ENUM(session_stats, PLUGIN_VAR_RQCMDARG,
-       "Controls query response time statistics collection for the current "
-       "session: ON - enable, OFF - disable, GLOBAL - use "
-       "query_response_time_stats value", NULL, NULL,
-       session_stat_global, &session_stat_typelib);
 
 static struct st_mysql_sys_var *query_response_time_info_vars[]=
 {
@@ -127,7 +69,6 @@ static struct st_mysql_sys_var *query_response_time_info_vars[]=
 #ifndef DBUG_OFF
   MYSQL_SYSVAR(exec_time_debug),
 #endif
-  MYSQL_SYSVAR(session_stats),
   NULL
 };
 
@@ -163,29 +104,11 @@ static int query_response_time_info_init(void *p)
 {
   ST_SCHEMA_TABLE *i_s_query_response_time= (ST_SCHEMA_TABLE *) p;
   i_s_query_response_time->fields_info= query_response_time_fields_info;
-  if (!my_strcasecmp(system_charset_info, i_s_query_response_time->table_name,
-                     "QUERY_RESPONSE_TIME"))
-    i_s_query_response_time->fill_table= query_response_time_fill;
-  else if (!my_strcasecmp(system_charset_info,
-                          i_s_query_response_time->table_name,
-                          "QUERY_RESPONSE_TIME_READ"))
-    i_s_query_response_time->fill_table= query_response_time_fill_ro;
-  else if (!my_strcasecmp(system_charset_info,
-                          i_s_query_response_time->table_name,
-                          "QUERY_RESPONSE_TIME_WRITE"))
-    i_s_query_response_time->fill_table= query_response_time_fill_rw;
-  else
-    DBUG_ASSERT(0);
+  i_s_query_response_time->fill_table= query_response_time_fill;
   query_response_time_init();
   return 0;
 }
 
-static int query_response_time_info_init_main(void *p)
-{
-  int res= query_response_time_info_init(p);
-  qrt_vars_initialized.set();
-  return res;
-}
 
 static int query_response_time_info_deinit(void *arg __attribute__((unused)))
 {
@@ -194,25 +117,10 @@ static int query_response_time_info_deinit(void *arg __attribute__((unused)))
   return 0;
 }
 
-static int query_response_time_info_deinit_main(void *arg)
-{
-  qrt_vars_initialized.clear();
-  return query_response_time_info_deinit(arg);
-}
 
 static struct st_mysql_information_schema query_response_time_info_descriptor=
 { MYSQL_INFORMATION_SCHEMA_INTERFACE_VERSION };
 
-static bool query_response_time_should_log(MYSQL_THD thd)
-{
-  const enum session_stat session_stat_val= qrt_vars_initialized.is_set() ?
-    static_cast<session_stat>(THDVAR(thd, session_stats)) :
-    session_stat_off;
-  return (session_stat_val == session_stat_on)
-    || (session_stat_val == session_stat_global
-        && opt_query_response_time_stats);
-}
-
 static void query_response_time_audit_notify(MYSQL_THD thd,
                                              unsigned int event_class,
                                              const void *event)
@@ -221,7 +129,7 @@ static void query_response_time_audit_notify(MYSQL_THD thd,
     (const struct mysql_event_general *) event;
   DBUG_ASSERT(event_class == MYSQL_AUDIT_GENERAL_CLASS);
   if (event_general->event_subclass == MYSQL_AUDIT_GENERAL_STATUS &&
-      query_response_time_should_log(thd))
+      opt_query_response_time_stats)
   {
     /*
      Get sql command id of currently executed statement
@@ -253,10 +161,7 @@ static void query_response_time_audit_notify(MYSQL_THD thd,
         &thd->lex->prepared_stmt_name;
       Statement *stmt=
         (Statement *)thd->stmt_map.find_by_name(name);
-      /* In case of EXECUTE <non-existing-PS>, keep SQLCOM_EXECUTE as the
-      command. */
-      if (likely(stmt && stmt->lex))
-        sql_command= stmt->lex->sql_command;
+      sql_command= stmt->lex->sql_command;
     }
     QUERY_TYPE query_type=
       (sql_command_flags[sql_command] & CF_CHANGES_DATA) ? WRITE : READ;
@@ -295,8 +200,8 @@ mysql_declare_plugin(query_response_time)
   "Percona and Sergey Vojtovich",
   "Query Response Time Distribution INFORMATION_SCHEMA Plugin",
   PLUGIN_LICENSE_GPL,
-  query_response_time_info_init_main,
-  query_response_time_info_deinit_main,
+  query_response_time_info_init,
+  query_response_time_info_deinit,
   0x0100,
   NULL,
   query_response_time_info_vars,
