@@ -1,20 +1,13 @@
-/* Copyright (c) 2010, 2019, Oracle and/or its affiliates. All rights reserved.
+/* Copyright (c) 2010, 2015, Oracle and/or its affiliates. All rights reserved.
 
    This program is free software; you can redistribute it and/or modify
-   it under the terms of the GNU General Public License, version 2.0,
-   as published by the Free Software Foundation.
-
-   This program is also distributed with certain software (including
-   but not limited to OpenSSL) that is licensed under separate terms,
-   as designated in a particular file or component or in included license
-   documentation.  The authors of MySQL hereby grant you an additional
-   permission to link the program and your derivative works with the
-   separately licensed software that they have included with MySQL.
+   it under the terms of the GNU General Public License as published by
+   the Free Software Foundation; version 2 of the License.
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License, version 2.0, for more details.
+   GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software Foundation,
@@ -25,7 +18,6 @@
 #include "unireg.h"
 #include "sql_parse.h"                          // check_access
 #include "global_threads.h"
-#include "mutex_lock.h"                         // Mutex_lock
 #ifdef HAVE_REPLICATION
 
 #include "sql_acl.h"                            // SUPER_ACL
@@ -70,7 +62,7 @@ extern TYPELIB binlog_checksum_typelib;
 
 extern "C" uint32
 *slave_list_key(SLAVE_INFO* si, size_t *len,
-		my_bool not_used MY_ATTRIBUTE((unused)))
+		my_bool not_used __attribute__((unused)))
 {
   *len = 4;
   return &si->server_id;
@@ -746,6 +738,7 @@ bool com_binlog_dump(THD *thd, char *packet, uint packet_length)
 {
   DBUG_ENTER("com_binlog_dump");
   ulong pos;
+  String slave_uuid;
   ushort flags= 0;
   const uchar* packet_position= (uchar *) packet;
   uint packet_bytes_todo= packet_length;
@@ -766,7 +759,8 @@ bool com_binlog_dump(THD *thd, char *packet, uint packet_length)
 
   DBUG_PRINT("info", ("pos=%lu flags=%d server_id=%d", pos, flags, thd->server_id));
 
-  kill_zombie_dump_threads(thd);
+  get_slave_uuid(thd, &slave_uuid);
+  kill_zombie_dump_threads(&slave_uuid);
 
   general_log_print(thd, thd->get_command(), "Log: '%s'  Pos: %ld",
                     packet + 10, (long) pos);
@@ -789,6 +783,7 @@ bool com_binlog_dump_gtid(THD *thd, char *packet, uint packet_length)
     Before going GA, we need to make this protocol extensible without
     breaking compatitibilty. /Alfranio.
   */
+  String slave_uuid;
   ushort flags= 0;
   uint32 data_size= 0;
   uint64 pos= 0;
@@ -820,7 +815,8 @@ bool com_binlog_dump_gtid(THD *thd, char *packet, uint packet_length)
   DBUG_PRINT("info", ("Slave %d requested to read %s at position %llu gtid set "
                       "'%s'.", thd->server_id, name, pos, gtid_string));
 
-  kill_zombie_dump_threads(thd);
+  get_slave_uuid(thd, &slave_uuid);
+  kill_zombie_dump_threads(&slave_uuid);
   general_log_print(thd, thd->get_command(), "Log: '%s' Pos: %llu GTIDs: '%s'",
                     name, pos, gtid_string);
   my_free(gtid_string);
@@ -853,7 +849,6 @@ void mysql_binlog_send(THD* thd, char* log_ident, my_off_t pos,
   char *log_file_name = linfo.log_file_name;
   char search_file_name[FN_REFLEN], *name;
 
-  bool is_index_file_reopened_on_binlog_disable= false;
   ulong ev_offset;
   bool using_gtid_protocol= slave_gtid_executed != NULL;
   bool searching_first_gtid= using_gtid_protocol;
@@ -870,7 +865,7 @@ void mysql_binlog_send(THD* thd, char* log_ident, my_off_t pos,
   bool time_for_hb_event= false;
   int error= 0;
   const char *errmsg = "Unknown error";
-  char error_text[MAX_SLAVE_ERRMSG]= {0}; // to be send to slave via my_message()
+  char error_text[MAX_SLAVE_ERRMSG]; // to be send to slave via my_message()
   NET* net = &thd->net;
   mysql_mutex_t *log_lock;
   mysql_cond_t *log_cond;
@@ -894,7 +889,7 @@ void mysql_binlog_send(THD* thd, char* log_ident, my_off_t pos,
   Diagnostics_area temp_da;
   Diagnostics_area *saved_da= thd->get_stmt_da();
   thd->set_stmt_da(&temp_da);
-  bool was_killed_by_duplicate_slave_id= false;
+  bool was_killed_by_duplicate_slave_uuid= false;
 
   DBUG_ENTER("mysql_binlog_send");
   DBUG_PRINT("enter",("log_ident: '%s'  pos: %ld", log_ident, (long) pos));
@@ -1015,7 +1010,7 @@ void mysql_binlog_send(THD* thd, char* log_ident, my_off_t pos,
       */
       if (!gtid_state->get_lost_gtids()->is_subset(slave_gtid_executed))
       {
-        mysql_bin_log.report_missing_purged_gtids(slave_gtid_executed, &errmsg);
+        errmsg= ER(ER_MASTER_HAS_PURGED_REQUIRED_GTIDS);
         my_errno= ER_MASTER_FATAL_ERROR_READING_BINLOG;
         global_sid_lock->unlock();
         GOTO_ERR;
@@ -1433,9 +1428,9 @@ void mysql_binlog_send(THD* thd, char* log_ident, my_off_t pos,
         {
           /*
              Skip groups in the binlogs which don't have any gtid event
-             logged before them. When opt_gtid_deployment_step is ON, the server
+             logged before them. When gtid_deployment_step is ON, the server
              doesn't generate GTID and so no gtid_event is logged before binlog
-             events. But when opt_gtid_deployment_step is OFF, the server starts
+             events. But when gtid_deployment_step is OFF, the server starts
              writing gtid_events in the middle of active binlog. When slave
              connects with gtid_protocol, master needs to skip binlog events
              which don't have corresponding gtid_event.
@@ -1944,65 +1939,18 @@ void mysql_binlog_send(THD* thd, char* log_ident, my_off_t pos,
 
     if (goto_next_binlog)
     {
-      DBUG_EXECUTE_IF("waiting_for_disable_binlog",
-                      {
-                      const char act[]= "now "
-                      "signal dump_thread_reached_wait_point "
-                      "wait_for continue_dump_thread no_clear_event";
-                      DBUG_ASSERT(!debug_sync_set_action(current_thd,
-                                                         STRING_WITH_LEN(act)));
-                      };);
-
       // clear flag because we open a new binlog
       binlog_has_previous_gtids_log_event= false;
 
       THD_STAGE_INFO(thd, stage_finished_reading_one_binlog_switching_to_next_binlog);
-      /*
-        When moving to next binlog, always check if binlog is enabled or not.
-        There can be critical errors like for example out of memory scenarios
-        which prevent mysqld server from writing to binlog. In those cases
-        server refers to binlog_error_action variable and takes the appropriate
-        action. If users choose to ignore the error then binary log will be
-        disabled and server will continue to do its work. In such cases dump
-        thread which is trying to move to the next log will fail as binlog index
-        file and binlog file are already closed and their corresponding caches
-        are also cleared.
-
-        Hence first check if binary log is enabled or not. If enabled look for
-        the next binary log in the index file. If it is disabled open the index
-        file once again and check if there any more binary logs that needs to be
-        sent. Keep reading binary log files until find_next_log returns empty.
-        If there is an error during open index file or we sent all binary logs
-        then ER_MASTER_FATAL_ERROR_READING_BINLOG is raised.
-      */
-      mysql_bin_log.lock_index();
-      if (!mysql_bin_log.is_open())
-      {
-        if (mysql_bin_log.open_index_file(mysql_bin_log.get_index_fname(),
-                                          linfo.log_file_name,FALSE))
-        {
-          errmsg = "Binary log is not open and failed to open index file to "
-            "retrieve next file.";
-          my_errno= ER_MASTER_FATAL_ERROR_READING_BINLOG;
-          mysql_bin_log.unlock_index();
-          GOTO_ERR;
-        }
-        is_index_file_reopened_on_binlog_disable= true;
-      }
-      if (mysql_bin_log.find_next_log(&linfo, 0))
-      {
-        DBUG_EXECUTE_IF("waiting_for_disable_binlog",
-                        {
-                        const char act[]= "now signal consumed_binlog";
-                        DBUG_ASSERT(!debug_sync_set_action(current_thd,
-                                                           STRING_WITH_LEN(act)));
-                        };);
+      switch (mysql_bin_log.find_next_log(&linfo, 1)) {
+      case 0:
+        break;
+      default:
         errmsg = "could not find next log";
         my_errno= ER_MASTER_FATAL_ERROR_READING_BINLOG;
-        mysql_bin_log.unlock_index();
         GOTO_ERR;
       }
-      mysql_bin_log.unlock_index();
 
       end_io_cache(&log);
       mysql_file_close(file, MYF(MY_WME));
@@ -2047,11 +1995,11 @@ end:
     reconnect anymore.
   */
   mysql_mutex_lock(&thd->LOCK_thd_data);
-  was_killed_by_duplicate_slave_id= thd->duplicate_slave_id;
+  was_killed_by_duplicate_slave_uuid= thd->duplicate_slave_uuid;
   mysql_mutex_unlock(&thd->LOCK_thd_data);
-  if (was_killed_by_duplicate_slave_id)
+  if (was_killed_by_duplicate_slave_uuid)
   {
-    errmsg= "A slave with the same server_uuid/server_id as this slave "
+    errmsg= "A slave with the same server_uuid as this slave "
             "has connected to the master";
     my_errno= ER_MASTER_FATAL_ERROR_READING_BINLOG;
     goto err;
@@ -2093,9 +2041,6 @@ err:
     error_text[sizeof(error_text) - 1]= '\0';
   }
   end_io_cache(&log);
-  if (is_index_file_reopened_on_binlog_disable)
-    mysql_bin_log.close(LOG_CLOSE_INDEX, true/*need_lock_log=true*/,
-			true/*need_lock_index=true*/);
   if (has_transmit_started)
     (void) RUN_HOOK(binlog_transmit, transmit_stop, (thd, flags));
   /*
@@ -2132,7 +2077,6 @@ String *get_slave_uuid(THD *thd, String *value)
 
   if (value == NULL)
     return NULL;
-  Mutex_lock lock_guard(&thd->LOCK_thd_data);
   user_var_entry *entry=
     (user_var_entry*) my_hash_search(&thd->user_vars, name, sizeof(name)-1);
   if (entry && entry->length() > 0)
@@ -2140,65 +2084,48 @@ String *get_slave_uuid(THD *thd, String *value)
     value->copy(entry->ptr(), entry->length(), NULL);
     return value;
   }
-
-  return NULL;
+  else
+    return NULL;
 }
 
 /*
 
   Kill all Binlog_dump threads which previously talked to the same slave
-  ("same" means with the same UUID(for slave versions >= 5.6) or same server id
-  (for slave versions < 5.6). Indeed, if the slave stops, if the
+  ("same" means with the same server id). Indeed, if the slave stops, if the
   Binlog_dump thread is waiting (mysql_cond_wait) for binlog update, then it
   will keep existing until a query is written to the binlog. If the master is
   idle, then this could last long, and if the slave reconnects, we could have 2
   Binlog_dump threads in SHOW PROCESSLIST, until a query is written to the
   binlog. To avoid this, when the slave reconnects and sends COM_BINLOG_DUMP,
-  the master kills any existing thread with the slave's UUID/server id (if this id is
+  the master kills any existing thread with the slave's server id (if this id is
   not zero; it will be true for real slaves, but false for mysqlbinlog when it
   sends COM_BINLOG_DUMP to get a remote binlog dump).
 
   SYNOPSIS
     kill_zombie_dump_threads()
-    @param thd newly connected dump thread object
+    slave_uuid      the slave's UUID
 
 */
 
-void kill_zombie_dump_threads(THD *thd)
+
+void kill_zombie_dump_threads(String *slave_uuid)
 {
-  String slave_uuid;
-  get_slave_uuid(thd, &slave_uuid);
-  if (slave_uuid.length() == 0 && thd->server_id == 0)
+  if (slave_uuid->length() == 0)
     return;
+  DBUG_ASSERT(slave_uuid->length() == UUID_LENGTH);
 
   mysql_mutex_lock(&LOCK_thread_count);
   THD *tmp= NULL;
   Thread_iterator it= global_thread_list_begin();
   Thread_iterator end= global_thread_list_end();
-  bool is_zombie_thread= false;
   for (; it != end; ++it)
   {
-    if ((*it) != thd && ((*it)->get_command() == COM_BINLOG_DUMP ||
-                         (*it)->get_command() == COM_BINLOG_DUMP_GTID))
+    if ((*it) != current_thd && ((*it)->get_command() == COM_BINLOG_DUMP ||
+                                 (*it)->get_command() == COM_BINLOG_DUMP_GTID))
     {
       String tmp_uuid;
-      get_slave_uuid((*it), &tmp_uuid);
-      if (slave_uuid.length())
-      {
-        is_zombie_thread= (tmp_uuid.length() &&
-                           !strncmp(slave_uuid.c_ptr(),
-                                    tmp_uuid.c_ptr(), UUID_LENGTH));
-      }
-      else
-      {
-        /*
-          Check if it is a 5.5 slave's dump thread i.e., server_id should be
-          same && dump thread should not contain 'UUID'.
-        */
-        is_zombie_thread= (((*it)->server_id == thd->server_id) &&
-                           !tmp_uuid.length());
-      }
-      if (is_zombie_thread)
+      if (get_slave_uuid((*it), &tmp_uuid) != NULL &&
+          !strncmp(slave_uuid->c_ptr(), tmp_uuid.c_ptr(), UUID_LENGTH))
       {
         tmp= *it;
         mysql_mutex_lock(&tmp->LOCK_thd_data);	// Lock from delete
@@ -2215,30 +2142,17 @@ void kill_zombie_dump_threads(THD *thd)
       again. We just to do kill the thread ourselves.
     */
     if (log_warnings > 1)
-    {
-      if (slave_uuid.length())
-      {
-        sql_print_information("While initializing dump thread for slave with "
-                              "UUID <%s>, found a zombie dump thread with the "
-                              "same UUID. Master is killing the zombie dump "
-                              "thread(%lu).", slave_uuid.c_ptr(),
-                              tmp->thread_id);
-      }
-      else
-      {
-        sql_print_information("While initializing dump thread for slave with "
-                              "server_id <%u>, found a zombie dump thread with the "
-                              "same server_id. Master is killing the zombie dump "
-                              "thread(%lu).", thd->server_id,
-                              tmp->thread_id);
-      }
-    }
-    tmp->duplicate_slave_id= true;
+      sql_print_information("While initializing dump thread for slave with "
+                            "UUID <%s>, found a zombie dump thread with "
+                            "the same UUID. Master is killing the zombie dump "
+                            "thread(%lu).", slave_uuid->c_ptr(), tmp->thread_id);
+    tmp->duplicate_slave_uuid= true;
     tmp->awake(THD::KILL_QUERY);
     mysql_mutex_unlock(&tmp->LOCK_thd_data);
   }
 }
 
+
 /**
   Execute a RESET MASTER statement.
 
