@@ -2,20 +2,13 @@
    Copyright (c) 2002, 2015, Oracle and/or its affiliates. All rights reserved.
 
    This program is free software; you can redistribute it and/or modify
-   it under the terms of the GNU General Public License, version 2.0,
-   as published by the Free Software Foundation.
-
-   This program is also distributed with certain software (including
-   but not limited to OpenSSL) that is licensed under separate terms,
-   as designated in a particular file or component or in included license
-   documentation.  The authors of MySQL hereby grant you an additional
-   permission to link the program and your derivative works with the
-   separately licensed software that they have included with MySQL.
+   it under the terms of the GNU General Public License as published by
+   the Free Software Foundation; version 2 of the License.
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License, version 2.0, for more details.
+   GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
@@ -429,7 +422,6 @@ bool sp_head::execute(THD *thd, bool merge_da_on_success)
   bool cur_db_changed= FALSE;
   bool err_status= FALSE;
   uint ip= 0;
-  bool save_enable_slow_log = thd->enable_slow_log;
   sql_mode_t save_sql_mode;
   bool save_abort_on_warning;
   Query_arena *old_arena;
@@ -657,8 +649,6 @@ bool sp_head::execute(THD *thd, bool merge_da_on_success)
 
     thd->m_digest= parent_digest;
 
-    thd->enable_slow_log= save_enable_slow_log;
-
     if (i->free_list)
       cleanup_items(i->free_list);
 
@@ -1774,10 +1764,10 @@ bool sp_head::show_routine_code(THD *thd)
     */
     if (ip != i->get_ip())
     {
-      const char format[]= "Instruction at position %u has m_ip=%u";
+      const char *format= "Instruction at position %u has m_ip=%u";
       char tmp[sizeof(format) + 2 * sizeof(uint) + 1];
 
-      snprintf(tmp, sizeof(tmp), format, ip, i->get_ip());
+      sprintf(tmp, format, ip, i->get_ip());
       /*
         Since this is for debugging purposes only, we don't bother to
         introduce a special error code for it.
@@ -1969,7 +1959,7 @@ bool sp_head::add_used_tables_to_table_list(THD *thd,
 bool sp_head::check_show_access(THD *thd, bool *full_access)
 {
   TABLE_LIST tables;
-  memset(static_cast<void*>(&tables), 0, sizeof(tables));
+  memset(&tables, 0, sizeof(tables));
   tables.db= (char*) "mysql";
   tables.table_name= tables.alias= (char*) "proc";
 
