@@ -1,21 +1,14 @@
 /*
-   Copyright (c) 2007, 2016, Oracle and/or its affiliates. All rights reserved.
+   Copyright (c) 2007, 2013, Oracle and/or its affiliates. All rights reserved.
 
    This program is free software; you can redistribute it and/or modify
-   it under the terms of the GNU General Public License, version 2.0,
-   as published by the Free Software Foundation.
-
-   This program is also distributed with certain software (including
-   but not limited to OpenSSL) that is licensed under separate terms,
-   as designated in a particular file or component or in included license
-   documentation.  The authors of MySQL hereby grant you an additional
-   permission to link the program and your derivative works with the
-   separately licensed software that they have included with MySQL.
+   it under the terms of the GNU General Public License as published by
+   the Free Software Foundation; version 2 of the License.
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License, version 2.0, for more details.
+   GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
@@ -71,6 +64,9 @@ using std::max;
 static int increment_connection_count(THD* thd, bool use_lock);
 #endif
 
+// Uses the THD to update the global stats by user name and client IP
+void update_global_user_stats(THD* thd, bool create_user, time_t now);
+
 HASH global_user_stats;
 HASH global_client_stats;
 HASH global_thread_stats;
@@ -140,66 +136,64 @@ end:
 
 }
 
-static uchar *get_key_user_stats(USER_STATS *user_stats, size_t *length,
-                                 my_bool not_used MY_ATTRIBUTE((unused)))
+extern "C" uchar *get_key_user_stats(USER_STATS *user_stats, size_t *length,
+                         my_bool not_used __attribute__((unused)))
 {
   *length= user_stats->user_len;
   return (uchar*) user_stats->user;
 }
 
-/* Lookup function for my_hash tables with THREAD_STATS entries */
-static uchar *get_key_thread_stats(THREAD_STATS *thread_stats,
-                                   size_t *length,
-                                   my_bool not_used MY_ATTRIBUTE((unused)))
+extern "C" uchar *get_key_thread_stats(THREAD_STATS *thread_stats, size_t *length,
+                         my_bool not_used __attribute__((unused)))
 {
   *length= sizeof(my_thread_id);
   return (uchar *) &(thread_stats->id);
 }
 
-static void free_user_stats(USER_STATS* user_stats)
+void free_user_stats(USER_STATS* user_stats)
 {
   my_free((char *) user_stats);
 }
 
-static void free_thread_stats(THREAD_STATS* thread_stats)
+void free_thread_stats(THREAD_STATS* thread_stats)
 {
   my_free((char *) thread_stats);
 }
 
-/* Intialize an instance of USER_STATS */
-static void init_user_stats(USER_STATS *user_stats, const char *user,
-                            const char *priv_user, uint total_connections,
-                            uint total_ssl_connections,
-                            uint concurrent_connections,
-                            time_t connected_time, double busy_time,
-                            double cpu_time, ulonglong bytes_received,
-                            ulonglong bytes_sent,
-                            ulonglong binlog_bytes_written,
-                            ha_rows rows_fetched, ha_rows rows_updated,
-                            ha_rows rows_read, ulonglong select_commands,
-                            ulonglong update_commands,
-                            ulonglong other_commands,
-                            ulonglong commit_trans, ulonglong rollback_trans,
-                            ulonglong denied_connections,
-                            ulonglong lost_connections,
-                            ulonglong access_denied_errors,
-                            ulonglong empty_queries)
+void init_user_stats(USER_STATS *user_stats,
+                     const char *user,
+                     const char *priv_user,
+                     uint total_connections,
+                     uint total_ssl_connections,
+                     uint concurrent_connections,
+                     time_t connected_time,
+                     double busy_time,
+                     double cpu_time,
+                     ulonglong bytes_received,
+                     ulonglong bytes_sent,
+                     ulonglong binlog_bytes_written,
+                     ha_rows rows_fetched,
+                     ha_rows rows_updated,
+                     ha_rows rows_read,
+                     ulonglong select_commands,
+                     ulonglong update_commands,
+                     ulonglong other_commands,
+                     ulonglong commit_trans,
+                     ulonglong rollback_trans,
+                     ulonglong denied_connections,
+                     ulonglong lost_connections,
+                     ulonglong access_denied_errors,
+                     ulonglong empty_queries)
 {
   DBUG_ENTER("init_user_stats");
   DBUG_PRINT("info",
              ("Add user_stats entry for user %s - priv_user %s",
               user, priv_user));
-  user_stats->user_len=               strlen(user);
-  if (user_stats->user_len >= sizeof(user_stats->user))
-    user_stats->user_len= sizeof(user_stats->user) - 1;
-  memcpy(user_stats->user, user, user_stats->user_len);
-  user_stats->user[user_stats->user_len]= '\0';
+  strncpy(user_stats->user, user, sizeof(user_stats->user));
+  strncpy(user_stats->priv_user, priv_user, sizeof(user_stats->priv_user));
 
-  user_stats->priv_user_len=          strlen(priv_user);
-  if (user_stats->priv_user_len >= sizeof(user_stats->priv_user))
-    user_stats->priv_user_len= sizeof(user_stats->priv_user) - 1;
-  strncpy(user_stats->priv_user, priv_user, user_stats->priv_user_len);
-  user_stats->priv_user[user_stats->priv_user_len]= '\0';
+  user_stats->user_len=               strlen(user_stats->user);
+  user_stats->priv_user_len=          strlen(user_stats->priv_user);
 
   user_stats->total_connections=      total_connections;
   user_stats->total_ssl_connections=  total_ssl_connections;
@@ -225,25 +219,29 @@ static void init_user_stats(USER_STATS *user_stats, const char *user,
   DBUG_VOID_RETURN;
 }
 
-/* Intialize an instance of THREAD_STATS */
-static void init_thread_stats(THREAD_STATS *thread_stats, my_thread_id id,
-                              uint total_connections,
-                              uint total_ssl_connections,
-                              uint concurrent_connections,
-                              time_t connected_time,
-                              double busy_time, double cpu_time,
-                              ulonglong bytes_received,
-                              ulonglong bytes_sent,
-                              ulonglong binlog_bytes_written,
-                              ha_rows rows_fetched, ha_rows rows_updated,
-                              ha_rows rows_read, ulonglong select_commands,
-                              ulonglong update_commands,
-                              ulonglong other_commands, ulonglong commit_trans,
-                              ulonglong rollback_trans,
-                              ulonglong denied_connections,
-                              ulonglong lost_connections,
-                              ulonglong access_denied_errors,
-                              ulonglong empty_queries)
+void init_thread_stats(THREAD_STATS *thread_stats,
+                     my_thread_id id,
+                     uint total_connections,
+                     uint total_ssl_connections,
+                     uint concurrent_connections,
+                     time_t connected_time,
+                     double busy_time,
+                     double cpu_time,
+                     ulonglong bytes_received,
+                     ulonglong bytes_sent,
+                     ulonglong binlog_bytes_written,
+                     ha_rows rows_fetched,
+                     ha_rows rows_updated,
+                     ha_rows rows_read,
+                     ulonglong select_commands,
+                     ulonglong update_commands,
+                     ulonglong other_commands,
+                     ulonglong commit_trans,
+                     ulonglong rollback_trans,
+                     ulonglong denied_connections,
+                     ulonglong lost_connections,
+                     ulonglong access_denied_errors,
+                     ulonglong empty_queries)
 {
   DBUG_ENTER("init_thread_stats");
   DBUG_PRINT("info",
@@ -301,19 +299,19 @@ void init_global_thread_stats(void)
                 0, 0, (my_hash_get_key) get_key_thread_stats,
                 (my_hash_free_key) free_thread_stats, 0))
   {
-    sql_print_error("Initializing global_thread_stats failed.");
+    sql_print_error("Initializing global_client_stats failed.");
     exit(1);
   }
 }
 
-static uchar *get_key_table_stats(TABLE_STATS *table_stats, size_t *length,
-                                  my_bool not_used MY_ATTRIBUTE((unused)))
+extern "C" uchar *get_key_table_stats(TABLE_STATS *table_stats, size_t *length,
+                                     my_bool not_used __attribute__((unused)))
 {
   *length= table_stats->table_len;
   return (uchar*) table_stats->table;
 }
 
-static void free_table_stats(TABLE_STATS* table_stats)
+extern "C" void free_table_stats(TABLE_STATS* table_stats)
 {
   my_free((char*) table_stats);
 }
@@ -328,14 +326,14 @@ void init_global_table_stats(void)
   }
 }
 
-static uchar *get_key_index_stats(INDEX_STATS *index_stats, size_t *length,
-                                  my_bool not_used MY_ATTRIBUTE((unused)))
+extern "C" uchar *get_key_index_stats(INDEX_STATS *index_stats, size_t *length,
+                                     my_bool not_used __attribute__((unused)))
 {
   *length= index_stats->index_len;
   return (uchar*) index_stats->index;
 }
 
-static void free_index_stats(INDEX_STATS* index_stats)
+extern "C" void free_index_stats(INDEX_STATS* index_stats)
 {
   my_free((char*) index_stats);
 }
@@ -653,54 +651,6 @@ void update_global_user_stats(THD* thd, bool create_user, time_t now)
   mysql_mutex_unlock(&LOCK_global_user_client_stats);
 }
 
-static void clear_stats_concurrent_connections(HASH* stats)
-{
-  for (ulong idx= 0; idx < stats->records; idx++)
-  {
-    USER_STATS* const user_stats=
-      reinterpret_cast<USER_STATS*>(my_hash_element(stats, idx));
-    user_stats->concurrent_connections= 0;
-  }
-}
-
-static void inc_stats_concurrent_conn(HASH* stats,
-				      const char* user_string, int cnt)
-{
-  USER_STATS* const user_stats=
-    reinterpret_cast<USER_STATS*>(my_hash_search(stats,
-          reinterpret_cast<const uchar*>(user_string),
-          strlen(user_string)));
-  if (user_stats)
-    user_stats->concurrent_connections+= cnt;
-}
-
-/**
-  Update number of concurrent connections for user_stats and client_stats
-  based on account resource limits
-*/
-void refresh_concurrent_conn_stats()
-{
-  mysql_mutex_lock(&LOCK_user_conn);
-
-  mysql_mutex_lock(&LOCK_global_user_client_stats);
-  clear_stats_concurrent_connections(&global_user_stats);
-  clear_stats_concurrent_connections(&global_client_stats);
-  mysql_mutex_unlock(&LOCK_global_user_client_stats);
-
-  for (ulong idx= 0; idx < hash_user_connections.records; idx++)
-  {
-    const struct user_conn* const uc=
-      reinterpret_cast<struct user_conn*>(
-          my_hash_element(&hash_user_connections, idx));
-    mysql_mutex_lock(&LOCK_global_user_client_stats);
-    inc_stats_concurrent_conn(&global_user_stats, uc->user, uc->connections);
-    inc_stats_concurrent_conn(&global_client_stats, uc->host, uc->connections);
-    mysql_mutex_unlock(&LOCK_global_user_client_stats);
-  }
-
-  mysql_mutex_unlock(&LOCK_user_conn);
-}
-
 /*
   check if user has already too many connections
 
@@ -915,10 +865,6 @@ void release_user_connection(THD *thd)
   DBUG_VOID_RETURN;
 }
 
-void refresh_concurrent_conn_stats()
-{
-}
-
 #endif /* NO_EMBEDDED_ACCESS_CHECKS */
 
 /*
@@ -927,7 +873,7 @@ void refresh_concurrent_conn_stats()
 */
 
 extern "C" uchar *get_key_conn(user_conn *buff, size_t *length,
-            my_bool not_used MY_ATTRIBUTE((unused)))
+            my_bool not_used __attribute__((unused)))
 {
   *length= buff->len;
   return (uchar*) buff->user;
@@ -1038,7 +984,7 @@ bool thd_init_client_charset(THD *thd, uint cs_number)
       my_error(ER_WRONG_VALUE_FOR_VAR, MYF(0), "character_set_client",
                global_system_variables.character_set_client->csname);
       return true;
-    }
+    }    
     thd->variables.character_set_client=
       global_system_variables.character_set_client;
     thd->variables.collation_connection=
@@ -1335,7 +1281,6 @@ bool login_connection(THD *thd)
   my_net_set_write_timeout(net, connect_timeout);
 
   error= check_connection(thd);
-  MYSQL_AUDIT_NOTIFY_CONNECTION_CONNECT(thd);
   thd->protocol->end_statement();
 
   if (error)
@@ -1505,6 +1450,7 @@ bool thd_prepare_connection(THD *thd)
   bool rc;
   lex_start(thd);
   rc= login_connection(thd);
+  MYSQL_AUDIT_NOTIFY_CONNECTION_CONNECT(thd);
   if (rc)
     return rc;
 
