@@ -1,20 +1,13 @@
-/* Copyright (c) 2000, 2017, Oracle and/or its affiliates. All rights reserved.
+/* Copyright (c) 2000, 2015, Oracle and/or its affiliates. All rights reserved.
 
    This program is free software; you can redistribute it and/or modify
-   it under the terms of the GNU General Public License, version 2.0,
-   as published by the Free Software Foundation.
-
-   This program is also distributed with certain software (including
-   but not limited to OpenSSL) that is licensed under separate terms,
-   as designated in a particular file or component or in included license
-   documentation.  The authors of MySQL hereby grant you an additional
-   permission to link the program and your derivative works with the
-   separately licensed software that they have included with MySQL.
+   it under the terms of the GNU General Public License as published by
+   the Free Software Foundation; version 2 of the License.
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License, version 2.0, for more details.
+   GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software Foundation,
@@ -459,7 +452,7 @@ int mysql_update(THD *thd,
   /* Update the table->file->stats.records number */
   table->file->info(HA_STATUS_VARIABLE | HA_STATUS_NO_LOCK);
 
-  table->mark_columns_needed_for_update(false/*mark_binlog_columns=false*/);
+  table->mark_columns_needed_for_update();
   select= make_select(table, 0, 0, conds, 0, &error);
 
   { // Enter scope for optimizer trace wrapper
@@ -509,9 +502,7 @@ int mysql_update(THD *thd,
       goto exit_without_my_ok;
     }
   }
-
-  if (select_lex->has_ft_funcs() && init_ftfuncs(thd, select_lex, 1))
-    goto exit_without_my_ok;
+  init_ftfuncs(thd, select_lex, 1);
 
   table->update_const_key_parts(conds);
   order= simple_remove_const(order, conds);
@@ -539,7 +530,7 @@ int mysql_update(THD *thd,
 #ifdef WITH_PARTITION_STORAGE_ENGINE
   used_key_is_modified|= partition_key_modified(table, table->write_set);
 #endif
-  table->mark_columns_per_binlog_row_image();
+
   using_filesort= order && (need_sort||used_key_is_modified);
   if (thd->lex->describe)
   {
@@ -695,7 +686,6 @@ int mysql_update(THD *thd,
       if (reinit_io_cache(&tempfile,READ_CACHE,0L,0,0))
 	error=1; /* purecov: inspected */
       select->file=tempfile;			// Read row ptrs from this file
-      setup_io_cache(&select->file);
       if (error >= 0)
         goto exit_without_my_ok;
     }
@@ -749,13 +739,6 @@ int mysql_update(THD *thd,
       check_constant_expressions(values))
     read_removal= table->check_read_removal(select->quick->index);
 
-  error= table->file->ha_fast_update(thd, fields, values, conds);
-  if (error == 0)
-    error= -1; // error < 0 means really no error at all (see below)
-  else if (error != ENOTSUP) {
-    error= 1;
-  }
-  else
   while (!(error=info.read_record(&info)) && !thd->killed)
   {
     thd->inc_examined_row_count(1);
@@ -843,8 +826,7 @@ int mysql_update(THD *thd,
             error= 0;
 	}
  	else if (!ignore ||
-                 table->file->is_fatal_error(error, HA_CHECK_DUP_KEY |
-                                                    HA_CHECK_FK_ERROR))
+                 table->file->is_fatal_error(error, HA_CHECK_DUP_KEY))
 	{
           /*
             If (ignore && error is ignorable) we don't have to
@@ -852,17 +834,13 @@ int mysql_update(THD *thd,
           */
           myf flags= 0;
 
-          if (table->file->is_fatal_error(error, HA_CHECK_DUP_KEY |
-                                                 HA_CHECK_FK_ERROR))
+          if (table->file->is_fatal_error(error, HA_CHECK_DUP_KEY))
             flags|= ME_FATALERROR; /* Other handler errors are fatal */
 
 	  table->file->print_error(error,MYF(flags));
 	  error= 1;
 	  break;
 	}
-        else if (ignore && !table->file->is_fatal_error(error,
-                                                        HA_CHECK_FK_ERROR))
-          warn_fk_constraint_violation(thd, table, error);
       }
 
       if (table->triggers &&
@@ -1878,12 +1856,12 @@ multi_update::initialize_tables(JOIN *join)
     {
       if (safe_update_on_fly(thd, join->join_tab, table_ref, all_tables))
       {
-        table->mark_columns_needed_for_update(true/*mark_binlog_columns=true*/);
+        table->mark_columns_needed_for_update();
 	table_to_update= table;			// Update table on the fly
 	continue;
       }
     }
-    table->mark_columns_needed_for_update(true/*mark_binlog_columns=true*/);
+    table->mark_columns_needed_for_update();
 
     /*
       enable uncacheable flag if we update a view with check option
@@ -2097,8 +2075,7 @@ bool multi_update::send_data(List<Item> &not_used_values)
         {
           updated--;
           if (!ignore ||
-              table->file->is_fatal_error(error, HA_CHECK_DUP_KEY |
-                                                 HA_CHECK_FK_ERROR))
+              table->file->is_fatal_error(error, HA_CHECK_DUP_KEY))
           {
             /*
               If (ignore && error == is ignorable) we don't have to
@@ -2106,16 +2083,12 @@ bool multi_update::send_data(List<Item> &not_used_values)
             */
             myf flags= 0;
 
-            if (table->file->is_fatal_error(error, HA_CHECK_DUP_KEY |
-                                                   HA_CHECK_FK_ERROR))
+            if (table->file->is_fatal_error(error, HA_CHECK_DUP_KEY))
               flags|= ME_FATALERROR; /* Other handler errors are fatal */
 
             table->file->print_error(error,MYF(flags));
             DBUG_RETURN(1);
           }
-          else if (ignore && !table->file->is_fatal_error(error,
-                                                          HA_CHECK_FK_ERROR))
-            warn_fk_constraint_violation(thd, table, error);
         }
         else
         {
@@ -2394,12 +2367,8 @@ int multi_update::do_updates()
         else if (local_error == HA_ERR_RECORD_IS_THE_SAME)
           local_error= 0;
         else if (!ignore ||
-                 table->file->is_fatal_error(local_error, HA_CHECK_DUP_KEY |
-                                                          HA_CHECK_FK_ERROR))
+                 table->file->is_fatal_error(local_error, HA_CHECK_DUP_KEY))
           goto err;
-       else if (ignore && !table->file->is_fatal_error(local_error,
-                                                          HA_CHECK_FK_ERROR))
-          warn_fk_constraint_violation(thd, table, local_error);
         else
           local_error= 0;
       }
