@@ -1,23 +1,16 @@
 #ifndef TABLE_INCLUDED
 #define TABLE_INCLUDED
 
-/* Copyright (c) 2000, 2017, Oracle and/or its affiliates. All rights reserved.
+/* Copyright (c) 2000, 2015, Oracle and/or its affiliates. All rights reserved.
 
    This program is free software; you can redistribute it and/or modify
-   it under the terms of the GNU General Public License, version 2.0,
-   as published by the Free Software Foundation.
-
-   This program is also distributed with certain software (including
-   but not limited to OpenSSL) that is licensed under separate terms,
-   as designated in a particular file or component or in included license
-   documentation.  The authors of MySQL hereby grant you an additional
-   permission to link the program and your derivative works with the
-   separately licensed software that they have included with MySQL.
+   it under the terms of the GNU General Public License as published by
+   the Free Software Foundation; version 2 of the License.
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License, version 2.0, for more details.
+   GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
@@ -530,11 +523,10 @@ typedef struct st_table_field_def
 class Table_check_intact
 {
 protected:
-  bool has_keys;
   virtual void report_error(uint code, const char *fmt, ...)= 0;
 
 public:
-  Table_check_intact() : has_keys(FALSE) {}
+  Table_check_intact() {}
   virtual ~Table_check_intact() {}
 
   /** Checks whether a table is intact. */
@@ -760,12 +752,6 @@ struct TABLE_SHARE
   */ 
   const File_parser *view_def;
 
-  /**
-    True in the case if tokudb read-free-replication is used for the table
-    without explicit pk and corresponding warning was issued to disable
-    repeated warning.
-  */
-  bool rfr_lookup_warning;
 
   /*
     Set share's table cache key and update its db and table name appropriately.
@@ -922,12 +908,6 @@ struct TABLE_SHARE
                             uint deadlock_weight);
   /** Release resources and free memory occupied by the table share. */
   void destroy();
-
-  /**
-    Checks if TABLE_SHARE has at least one field with
-    COLUMN_FORMAT_TYPE_COMPRESSED flag.
-  */
-  bool has_compressed_columns() const;
 };
 
 
@@ -1237,7 +1217,7 @@ public:
   void mark_columns_used_by_index_no_reset(uint index, MY_BITMAP *map);
   void mark_columns_used_by_index(uint index);
   void mark_auto_increment_column(void);
-  void mark_columns_needed_for_update(bool mark_binlog_columns);
+  void mark_columns_needed_for_update(void);
   void mark_columns_needed_for_delete(void);
   void mark_columns_needed_for_insert(void);
   void mark_columns_per_binlog_row_image(void);
@@ -1315,38 +1295,6 @@ public:
   {
     created= false;
   }
-
-  /**
-    Checks if TABLE has at least one field with
-    COLUMN_FORMAT_TYPE_COMPRESSED flag.
-  */
-  bool has_compressed_columns() const;
-
-  /**
-    Checks if TABLE has at least one field with
-    COLUMN_FORMAT_TYPE_COMPRESSED flag and non-empty
-    zip_dict.
-  */
-  bool has_compressed_columns_with_dictionaries() const;
-
-  /**
-    Updates zip_dict_name in the TABLE's field definitions based on the
-    values from the supplied list of Create_field objects.
-  */
-  void update_compressed_columns_info(const List<Create_field>& fields);
-private:
-  bool should_binlog_drop_if_temp_flag;
-
-public:
-  void set_binlog_drop_if_temp(bool should_binlog)
-  {
-    should_binlog_drop_if_temp_flag= should_binlog;
-  }
-
-  bool should_binlog_drop_if_temp(void) const
-  {
-    return should_binlog_drop_if_temp_flag;
-  }
 };
 
 
@@ -1570,7 +1518,7 @@ struct Name_resolution_context;
 struct LEX;
 struct TABLE_LIST
 {
-  TABLE_LIST() { memset(static_cast<void*>(this), 0, sizeof(*this)); }
+  TABLE_LIST() {}                          /* Remove gcc warning */
 
   /**
     Prepare TABLE_LIST that consists of one table instance to use in
@@ -1583,7 +1531,7 @@ struct TABLE_LIST
                              const char *alias_arg,
                              enum thr_lock_type lock_type_arg)
   {
-    new (this) TABLE_LIST;
+    memset(this, 0, sizeof(*this));
     db= (char*) db_name_arg;
     db_length= db_length_arg;
     table_name= (char*) table_name_arg;
