@@ -11,7 +11,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA */
+   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */
 
 #include <my_global.h>
 #include <violite.h>
@@ -67,23 +67,20 @@ extern bool do_command(THD*);
   using my_thread_init() and freed with my_thread_end().
 
 */
-class Worker_thread_context
+struct Worker_thread_context
 {
-#ifdef HAVE_PSI_THREAD_INTERFACE
-  PSI_thread * const psi_thread;
-#endif
-  st_my_thread_var * const mysys_var;
+  PSI_thread *psi_thread;
+  st_my_thread_var* mysys_var;
 
-public:
-  Worker_thread_context() :
-#ifdef HAVE_PSI_THREAD_INTERFACE
-    psi_thread(PSI_THREAD_CALL(get_thread)()),
-#endif
-    mysys_var(static_cast<st_my_thread_var *>(pthread_getspecific(THR_KEY_mysys)))
+  void save()
   {
+#ifdef HAVE_PSI_THREAD_INTERFACE
+    psi_thread= PSI_THREAD_CALL(get_thread)();
+#endif
+    mysys_var= (st_my_thread_var *)pthread_getspecific(THR_KEY_mysys);
   }
 
-  ~Worker_thread_context()
+  void restore()
   {
 #ifdef HAVE_PSI_THREAD_INTERFACE
     PSI_THREAD_CALL(set_thread)(psi_thread);
@@ -114,15 +111,13 @@ static bool thread_attach(THD* thd)
 extern PSI_statement_info stmt_info_new_packet;
 #endif
 
-#ifdef HAVE_PSI_INTERFACE
-static void threadpool_net_before_header_psi_noop(struct st_net * /* net */,
-                                                  void * /* user_data */,
-                                                  size_t /* count */)
+void threadpool_net_before_header_psi_noop(struct st_net * /* net */,
+                                           void * /* user_data */,
+                                           size_t /* count */)
 { }
 
-static void threadpool_net_after_header_psi(struct st_net *net,
-                                            void *user_data,
-                                            size_t /* count */, my_bool rc)
+void threadpool_net_after_header_psi(struct st_net *net, void *user_data,
+                                     size_t /* count */, my_bool rc)
 {
   THD *thd;
   thd= static_cast<THD*> (user_data);
@@ -162,9 +157,8 @@ static void threadpool_net_after_header_psi(struct st_net *net,
     thd->m_server_idle = false;
   }
 }
-#endif
 
-static void threadpool_init_net_server_extension(THD *thd)
+void threadpool_init_net_server_extension(THD *thd)
 {
 #ifdef HAVE_PSI_INTERFACE
   /* Start with a clean state for connection events. */
@@ -186,6 +180,7 @@ int threadpool_add_connection(THD *thd)
 {
   int retval=1;
   Worker_thread_context worker_context;
+  worker_context.save();
 
   /*
     Create a new connection context: mysys_thread_var and PSI thread
@@ -198,6 +193,7 @@ int threadpool_add_connection(THD *thd)
   if (!thd->mysys_var)
   {
     /* Out of memory? */
+    worker_context.restore();
     return 1;
   }
 
@@ -217,7 +213,6 @@ int threadpool_add_connection(THD *thd)
 
   if (!setup_connection_thread_globals(thd))
   {
-    lex_start(thd);
     bool rc= login_connection(thd);
     MYSQL_AUDIT_NOTIFY_CONNECTION_CONNECT(thd);
     if (!rc)
@@ -242,6 +237,7 @@ int threadpool_add_connection(THD *thd)
                              (char *) thd->security_ctx->host_or_ip);
     }
   }
+  worker_context.restore();
   thd->system_tid = -1;
   return retval;
 }
@@ -249,7 +245,9 @@ int threadpool_add_connection(THD *thd)
 
 void threadpool_remove_connection(THD *thd)
 {
+
   Worker_thread_context worker_context;
+  worker_context.save();
 
   thread_attach(thd);
   thd->net.reading_or_writing= 0;
@@ -271,6 +269,8 @@ void threadpool_remove_connection(THD *thd)
   my_thread_end();
 
   mysql_cond_broadcast(&COND_thread_count);
+
+  worker_context.restore();
 }
 
 /**
@@ -279,7 +279,8 @@ void threadpool_remove_connection(THD *thd)
 int threadpool_process_request(THD *thd)
 {
   int retval= 0;
-  Worker_thread_context worker_context;
+  Worker_thread_context  worker_context;
+  worker_context.save();
 
   thread_attach(thd);
 
@@ -340,6 +341,7 @@ end:
     thd->m_server_idle= true;
   }
 
+  worker_context.restore();
   thd->system_tid = -1;
   return retval;
 }
