@@ -1,22 +1,14 @@
 /*****************************************************************************
 
-Copyright (c) 1995, 2017, Oracle and/or its affiliates. All Rights Reserved.
+Copyright (c) 1995, 2015, Oracle and/or its affiliates. All Rights Reserved.
 
-This program is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License, version 2.0,
-as published by the Free Software Foundation.
+This program is free software; you can redistribute it and/or modify it under
+the terms of the GNU General Public License as published by the Free Software
+Foundation; version 2 of the License.
 
-This program is also distributed with certain software (including
-but not limited to OpenSSL) that is licensed under separate terms,
-as designated in a particular file or component or in included license
-documentation.  The authors of MySQL hereby grant you an additional
-permission to link the program and your derivative works with the
-separately licensed software that they have included with MySQL.
-
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License, version 2.0, for more details.
+This program is distributed in the hope that it will be useful, but WITHOUT
+ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License along with
 this program; if not, write to the Free Software Foundation, Inc.,
@@ -317,8 +309,6 @@ buf_flush_init_flush_rbt(void)
 
 		buf_flush_list_mutex_enter(buf_pool);
 
-		ut_ad(buf_pool->flush_rbt == NULL);
-
 		/* Create red black tree for speedy insertions in flush list. */
 		buf_pool->flush_rbt = rbt_create(
 			sizeof(buf_page_t*), buf_flush_block_cmp);
@@ -364,7 +354,6 @@ buf_flush_insert_into_flush_list(
 	buf_block_t*	block,		/*!< in/out: block which is modified */
 	lsn_t		lsn)		/*!< in: oldest modification */
 {
-	ut_ad(srv_shutdown_state != SRV_SHUTDOWN_FLUSH_PHASE);
 	ut_ad(log_flush_order_mutex_own());
 	ut_ad(mutex_own(&block->mutex));
 
@@ -423,7 +412,6 @@ buf_flush_insert_sorted_into_flush_list(
 	buf_page_t*	prev_b;
 	buf_page_t*	b;
 
-	ut_ad(srv_shutdown_state != SRV_SHUTDOWN_FLUSH_PHASE);
 	ut_ad(log_flush_order_mutex_own());
 	ut_ad(mutex_own(&block->mutex));
 	ut_ad(buf_block_get_state(block) == BUF_BLOCK_FILE_PAGE);
@@ -734,7 +722,6 @@ buf_flush_write_complete(
 	buf_page_set_io_fix(bpage, BUF_IO_NONE);
 
 	buf_pool->n_flush[flush_type]--;
-	ut_ad(buf_pool->n_flush[flush_type] != ULINT_MAX);
 
 	/* fprintf(stderr, "n pending flush %lu\n",
 	buf_pool->n_flush[flush_type]); */
@@ -1072,7 +1059,6 @@ buf_flush_page(
 		}
 
 		++buf_pool->n_flush[flush_type];
-		ut_ad(buf_pool->n_flush[flush_type] != 0);
 
 		mutex_exit(&buf_pool->flush_state_mutex);
 
@@ -1502,7 +1488,7 @@ It attempts to make 'max' blocks available in the free list. Note that
 it is a best effort attempt and it is not guaranteed that after a call
 to this function there will be 'max' blocks in the free list.
 @return number of blocks for which the write request was queued. */
-MY_ATTRIBUTE((nonnull))
+__attribute__((nonnull))
 static
 void
 buf_flush_LRU_list_batch(
@@ -1648,7 +1634,7 @@ Whether LRU or unzip_LRU is used depends on the state of the system.
 @return number of blocks for which either the write request was queued
 or in case of unzip_LRU the number of blocks actually moved to the
 free list */
-MY_ATTRIBUTE((nonnull))
+__attribute__((nonnull))
 static
 void
 buf_do_LRU_batch(
@@ -1768,7 +1754,7 @@ pages: to avoid deadlocks, this function must be written so that it cannot
 end up waiting for these latches! NOTE 2: in the case of a flush list flush,
 the calling thread is not allowed to own any latches on pages!
 @return number of blocks for which the write request was queued */
-MY_ATTRIBUTE((nonnull))
+__attribute__((nonnull))
 static
 void
 buf_flush_batch(
@@ -1946,7 +1932,7 @@ list.
 NOTE: The calling thread is not allowed to own any latches on pages!
 @return true if a batch was queued successfully. false if another batch
 of same type was already running. */
-MY_ATTRIBUTE((nonnull))
+__attribute__((nonnull))
 static
 bool
 buf_flush_LRU(
@@ -2218,14 +2204,13 @@ Clears up tail of the LRU lists:
 * Flush dirty pages at the tail of LRU to the disk
 The depth to which we scan each buffer pool is controlled by dynamic
 config parameter innodb_LRU_scan_depth.
-@return number of flushed and evicted pages */
+@return number of pages flushed */
 UNIV_INTERN
 ulint
 buf_flush_LRU_tail(void)
 /*====================*/
 {
 	ulint	total_flushed = 0;
-	ulint	total_evicted = 0;
 	ulint	start_time = ut_time_ms();
 	ulint	scan_depth[MAX_BUFFER_POOLS];
 	ulint	requested_pages[MAX_BUFFER_POOLS];
@@ -2291,7 +2276,6 @@ buf_flush_LRU_tail(void)
 				limited_scan[i]
 					= (previous_evicted[i] > n.evicted);
 				previous_evicted[i] = n.evicted;
-				total_evicted += n.evicted;
 
 				requested_pages[i] += lru_chunk_size;
 
@@ -2324,7 +2308,7 @@ buf_flush_LRU_tail(void)
 			MONITOR_LRU_BATCH_PAGES,
 			total_flushed);
 	}
-	return(total_flushed + total_evicted);
+	return(total_flushed);
 }
 
 /*********************************************************************//**
@@ -2575,28 +2559,29 @@ page_cleaner_flush_pages_if_needed(void)
 /*********************************************************************//**
 Puts the page_cleaner thread to sleep if it has finished work in less
 than a second */
-static void
-page_cleaner_sleep_if_needed(ut_monotonic_time next_loop_time) {
-	/* No sleep if we are cleaning the buffer pool during the shutdown
-	with everything else finished */
-	if (srv_shutdown_state == SRV_SHUTDOWN_FLUSH_PHASE)
-		return;
+static
+void
+page_cleaner_sleep_if_needed(
+/*=========================*/
+	ulint	next_loop_time)	/*!< in: time when next loop iteration
+				should start */
+{
+	ulint	cur_time = ut_time_ms();
 
-	const ut_monotonic_time cur_time = ut_monotonic_time_ms();
-
-	if (next_loop_time.ms > cur_time.ms) {
+	if (next_loop_time > cur_time) {
 		/* Get sleep interval in micro seconds. We use
 		ut_min() to avoid long sleep in case of
 		wrap around. */
-		os_thread_sleep(ut_min(
-		    1000000, (next_loop_time.ms - cur_time.ms) * 1000));
+		os_thread_sleep(ut_min(1000000,
+				(next_loop_time - cur_time)
+				 * 1000));
 	}
 }
 
 /*********************************************************************//**
 Returns the aggregate free list length over all buffer pool instances.
 @return total free list length. */
-MY_ATTRIBUTE((warn_unused_result))
+__attribute__((warn_unused_result))
 static
 ulint
 buf_get_total_free_list_length(void)
@@ -2612,52 +2597,38 @@ buf_get_total_free_list_length(void)
 	return result;
 }
 
-/** Returns the aggregate LRU list length over all buffer pool instances.
-@return total LRU list length. */
-MY_ATTRIBUTE((warn_unused_result))
-static
-ulint
-buf_get_total_LRU_list_length(void)
-{
-        ulint result = 0;
-
-        for (ulint i = 0; i < srv_buf_pool_instances; i++) {
-
-                result += UT_LIST_GET_LEN(buf_pool_from_array(i)->LRU);
-        }
-
-        return result;
-}
-
 /*********************************************************************//**
 Adjust the desired page cleaner thread sleep time for LRU flushes.  */
-MY_ATTRIBUTE((nonnull))
-static void
+__attribute__((nonnull))
+static
+void
 page_cleaner_adapt_lru_sleep_time(
-	ut_monotonic_time	* lru_sleep_time, /*!< in/out: desired page cleaner thread
-					sleep time for LRU flushes  */
-	ulint	lru_n_flushed)  /*!< in: number of flushed in previous batch */
+/*==============================*/
+	ulint*	lru_sleep_time,	/*!< in/out: desired page cleaner thread sleep
+				time for LRU flushes  */
+	ulint	lru_n_flushed) /*!< in: number of flushed in previous batch */
+
 {
-        ulint free_len = buf_get_total_free_list_length();
-        ulint max_free_len = ut_min(buf_get_total_LRU_list_length(),
-                        srv_LRU_scan_depth * srv_buf_pool_instances);
+	ulint free_len = buf_get_total_free_list_length();
+	ulint max_free_len = srv_LRU_scan_depth * srv_buf_pool_instances;
 
 	if (free_len < max_free_len / 100 && lru_n_flushed) {
 
 		/* Free lists filled less than 1%
 		and iteration was able to flush, no sleep */
-		lru_sleep_time->ms = 0;
+		*lru_sleep_time = 0;
 	} else if (free_len > max_free_len / 5
 		   || (free_len < max_free_len / 100 && lru_n_flushed == 0)) {
 
 		/* Free lists filled more than 20%
 		or no pages flushed in previous batch, sleep a bit more */
-		lru_sleep_time->ms += 1;
-		if (lru_sleep_time->ms > srv_cleaner_max_lru_time)
-			lru_sleep_time->ms = srv_cleaner_max_lru_time;
-	} else if (free_len < max_free_len / 20 && lru_sleep_time->ms >= 50) {
+		*lru_sleep_time += 50;
+		if (*lru_sleep_time > srv_cleaner_max_lru_time)
+			*lru_sleep_time = srv_cleaner_max_lru_time;
+	} else if (free_len < max_free_len / 20 && *lru_sleep_time >= 50) {
+
 		/* Free lists filled less than 5%, sleep a bit less */
-		lru_sleep_time->ms -= 50;
+		*lru_sleep_time -= 50;
 	} else {
 
 		/* Free lists filled between 5% and 20%, no change */
@@ -2667,7 +2638,7 @@ page_cleaner_adapt_lru_sleep_time(
 /*********************************************************************//**
 Get the desired page cleaner thread sleep time for flush list flushes.
 @return desired sleep time */
-MY_ATTRIBUTE((warn_unused_result))
+__attribute__((warn_unused_result))
 static
 ulint
 page_cleaner_adapt_flush_sleep_time(void)
@@ -2694,16 +2665,14 @@ extern "C" UNIV_INTERN
 os_thread_ret_t
 DECLARE_THREAD(buf_flush_page_cleaner_thread)(
 /*==========================================*/
-	void*	arg MY_ATTRIBUTE((unused)))
+	void*	arg __attribute__((unused)))
 			/*!< in: a dummy parameter required by
 			os_thread_create */
 {
-	my_thread_init();
-	ut_monotonic_time next_loop_time = ut_monotonic_time_ms();
-	next_loop_time.ms += 1000;
+	ulint	next_loop_time = ut_time_ms() + 1000;
 	ulint	n_flushed = 0;
 	ulint	last_activity = srv_get_activity_count();
-	ut_monotonic_time last_activity_time = ut_monotonic_time_ms();
+	ulint	last_activity_time = ut_time_ms();
 
 	ut_ad(!srv_read_only_mode);
 
@@ -2723,7 +2692,8 @@ DECLARE_THREAD(buf_flush_page_cleaner_thread)(
 	buf_page_cleaner_is_active = TRUE;
 
 	while (srv_shutdown_state == SRV_SHUTDOWN_NONE) {
-		ulint page_cleaner_sleep_time;
+
+		ulint	page_cleaner_sleep_time;
 		ibool	server_active;
 
 		srv_current_thread_priority = srv_cleaner_thread_priority;
@@ -2737,20 +2707,19 @@ DECLARE_THREAD(buf_flush_page_cleaner_thread)(
 			page_cleaner_sleep_if_needed(next_loop_time);
 		}
 
-		page_cleaner_sleep_time =
-		    page_cleaner_adapt_flush_sleep_time();
+		page_cleaner_sleep_time
+			= page_cleaner_adapt_flush_sleep_time();
 
-		next_loop_time.ms =
-		    ut_monotonic_time_ms().ms + page_cleaner_sleep_time;
+		next_loop_time = ut_time_ms() + page_cleaner_sleep_time;
 
 		server_active = srv_check_activity(last_activity);
-		if (server_active ||
-		    ut_monotonic_time_ms().ms - last_activity_time.ms <
-			1000) {
+		if (server_active
+		    || ut_time_ms() - last_activity_time < 1000) {
+
 			if (server_active) {
 
 				last_activity = srv_get_activity_count();
-				last_activity_time = ut_monotonic_time_ms();
+				last_activity_time = ut_time_ms();
 			}
 
 			/* Flush pages from flush_list if required */
@@ -2788,10 +2757,7 @@ DECLARE_THREAD(buf_flush_page_cleaner_thread)(
 	when SRV_SHUTDOWN_CLEANUP is set other threads like the master
 	and the purge threads may be working as well. We start flushing
 	the buffer pool but can't be sure that no new pages are being
-	dirtied until we enter SRV_SHUTDOWN_FLUSH_PHASE phase. Because
-	the LRU manager thread is also flushing at SRV_SHUTDOWN_CLEANUP
-	but not SRV_SHUTDOWN_FLUSH_PHASE, we only leave the
-	SRV_SHUTDOWN_CLEANUP loop when the LRU manager quits. */
+	dirtied until we enter SRV_SHUTDOWN_FLUSH_PHASE phase. */
 
 	do {
 		n_flushed = page_cleaner_do_flush_batch(PCT_IO(100), LSN_MAX);
@@ -2800,10 +2766,7 @@ DECLARE_THREAD(buf_flush_page_cleaner_thread)(
 		if (n_flushed == 0) {
 			os_thread_sleep(100000);
 		}
-
-		os_rmb;
-	} while (srv_shutdown_state == SRV_SHUTDOWN_CLEANUP
-		 || buf_lru_manager_is_active);
+	} while (srv_shutdown_state == SRV_SHUTDOWN_CLEANUP);
 
 	/* At this point all threads including the master and the purge
 	thread must have been suspended. */
@@ -2820,11 +2783,6 @@ DECLARE_THREAD(buf_flush_page_cleaner_thread)(
 	buf_flush_wait_batch_end(NULL, BUF_FLUSH_LIST);
 	buf_flush_wait_LRU_batch_end();
 
-#ifdef UNIV_DEBUG
-	os_rmb;
-	ut_ad(!buf_lru_manager_is_active);
-#endif
-
 	bool	success;
 
 	do {
@@ -2847,7 +2805,6 @@ DECLARE_THREAD(buf_flush_page_cleaner_thread)(
 thread_exit:
 	buf_page_cleaner_is_active = FALSE;
 
-	my_thread_end();
 	/* We count the number of threads in os_thread_exit(). A created
 	thread should always use that to exit and not use return() to exit. */
 	os_thread_exit(NULL);
@@ -2864,14 +2821,12 @@ extern "C" UNIV_INTERN
 os_thread_ret_t
 DECLARE_THREAD(buf_flush_lru_manager_thread)(
 /*==========================================*/
-	void*	arg MY_ATTRIBUTE((unused)))
+	void*	arg __attribute__((unused)))
 			/*!< in: a dummy parameter required by
 			os_thread_create */
 {
-	ut_monotonic_time next_loop_time = ut_monotonic_time_ms();
-	next_loop_time.ms += 1000;
-	ut_monotonic_time lru_sleep_time;
-	lru_sleep_time.ms = srv_cleaner_max_lru_time;
+	ulint	next_loop_time = ut_time_ms() + 1000;
+	ulint	lru_sleep_time = srv_cleaner_max_lru_time;
 	ulint	lru_n_flushed = 1;
 
 #ifdef UNIV_PFS_THREAD
@@ -2889,7 +2844,6 @@ DECLARE_THREAD(buf_flush_lru_manager_thread)(
 #endif /* UNIV_DEBUG_THREAD_CREATION */
 
 	buf_lru_manager_is_active = true;
-	os_wmb;
 
 	/* On server shutdown, the LRU manager thread runs through cleanup
 	phase to provide free pages for the master and purge threads.  */
@@ -2902,14 +2856,12 @@ DECLARE_THREAD(buf_flush_lru_manager_thread)(
 
 		page_cleaner_adapt_lru_sleep_time(&lru_sleep_time, lru_n_flushed);
 
-		next_loop_time.ms =
-		    ut_monotonic_time_ms().ms + lru_sleep_time.ms;
+		next_loop_time = ut_time_ms() + lru_sleep_time;
 
 		lru_n_flushed = buf_flush_LRU_tail();
 	}
 
 	buf_lru_manager_is_active = false;
-	os_wmb;
 
 	/* We count the number of threads in os_thread_exit(). A created
 	thread should always use that to exit and not use return() to exit. */
