@@ -1,6 +1,6 @@
 /*****************************************************************************
 
-Copyright (c) 2012, 2018, Oracle and/or its affiliates. All Rights Reserved.
+Copyright (c) 2012, 2015, Oracle and/or its affiliates. All Rights Reserved.
 
 This program is free software; you can redistribute it and/or modify it under
 the terms of the GNU General Public License as published by the Free Software
@@ -1335,27 +1335,13 @@ row_import::match_schema(
 	THD*		thd) UNIV_NOTHROW
 {
 	/* Do some simple checks. */
-	const unsigned relevant_flags = m_flags & ~DICT_TF_MASK_DATA_DIR;
-	const unsigned relevant_table_flags
-		= m_table->flags & ~DICT_TF_MASK_DATA_DIR;
 
-	if (relevant_flags != relevant_table_flags) {
-		if (dict_tf_to_row_format_string(relevant_flags) !=
-			dict_tf_to_row_format_string(relevant_table_flags)) {
-			ib_errf(thd, IB_LOG_LEVEL_ERROR,
-				ER_TABLE_SCHEMA_MISMATCH,
-				"Table flags don't match,"
-				"server table has %s "
-				"and the meta-data file has %s",
-				dict_tf_to_row_format_string(
-					relevant_table_flags),
-				dict_tf_to_row_format_string(
-					relevant_flags));
-		} else {
-			ib_errf(thd, IB_LOG_LEVEL_ERROR,
-				ER_TABLE_SCHEMA_MISMATCH,
-				"Table flags don't match");
-		}
+	if (m_flags != m_table->flags) {
+		ib_errf(thd, IB_LOG_LEVEL_ERROR, ER_TABLE_SCHEMA_MISMATCH,
+			 "Table flags don't match, server table has 0x%lx "
+			 "and the meta-data file has 0x%lx",
+			 (ulong) m_table->n_cols, (ulong) m_flags);
+
 		return(DB_ERROR);
 	} else if (m_table->n_cols != m_n_cols) {
 		ib_errf(thd, IB_LOG_LEVEL_ERROR, ER_TABLE_SCHEMA_MISMATCH,
@@ -1841,6 +1827,12 @@ PageConverter::update_records(
 
 		rec_t*	rec = m_rec_iter.current();
 
+		/* FIXME: Move out of the loop */
+
+		if (rec_get_status(rec) == REC_STATUS_NODE_PTR) {
+			break;
+		}
+
 		ibool	deleted = rec_get_deleted_flag(rec, comp);
 
 		/* For the clustered index we have to adjust the BLOB
@@ -1942,10 +1934,6 @@ PageConverter::update_index_page(
 		return(DB_SUCCESS);
 	}
 
-	if (!page_is_leaf(block->frame)) {
-		return (DB_SUCCESS);
-	}
-
 	return(update_records(block));
 }
 
@@ -2034,7 +2022,6 @@ PageConverter::update_page(
 	case FIL_PAGE_TYPE_XDES:
 		err = set_current_xdes(
 			buf_block_get_page_no(block), get_frame(block));
-		// fallthrough
 	case FIL_PAGE_INODE:
 	case FIL_PAGE_TYPE_TRX_SYS:
 	case FIL_PAGE_IBUF_FREE_LIST:
@@ -2192,7 +2179,7 @@ PageConverter::operator() (
 Clean up after import tablespace failure, this function will acquire
 the dictionary latches on behalf of the transaction if the transaction
 hasn't already acquired them. */
-static	MY_ATTRIBUTE((nonnull))
+static	__attribute__((nonnull))
 void
 row_import_discard_changes(
 /*=======================*/
@@ -2243,7 +2230,7 @@ row_import_discard_changes(
 
 /*****************************************************************//**
 Clean up after import tablespace. */
-static	MY_ATTRIBUTE((nonnull, warn_unused_result))
+static	__attribute__((nonnull, warn_unused_result))
 dberr_t
 row_import_cleanup(
 /*===============*/
@@ -2278,7 +2265,7 @@ row_import_cleanup(
 
 /*****************************************************************//**
 Report error during tablespace import. */
-static	MY_ATTRIBUTE((nonnull, warn_unused_result))
+static	__attribute__((nonnull, warn_unused_result))
 dberr_t
 row_import_error(
 /*=============*/
@@ -2306,7 +2293,7 @@ row_import_error(
 Adjust the root page index node and leaf node segment headers, update
 with the new space id. For all the table's secondary indexes.
 @return error code */
-static	MY_ATTRIBUTE((nonnull, warn_unused_result))
+static	__attribute__((nonnull, warn_unused_result))
 dberr_t
 row_import_adjust_root_pages_of_secondary_indexes(
 /*==============================================*/
@@ -2422,7 +2409,7 @@ row_import_adjust_root_pages_of_secondary_indexes(
 /*****************************************************************//**
 Ensure that dict_sys->row_id exceeds SELECT MAX(DB_ROW_ID).
 @return error code */
-static	MY_ATTRIBUTE((nonnull, warn_unused_result))
+static	__attribute__((nonnull, warn_unused_result))
 dberr_t
 row_import_set_sys_max_row_id(
 /*==========================*/
@@ -2572,7 +2559,7 @@ row_import_cfg_read_string(
 /*********************************************************************//**
 Write the meta data (index user fields) config file.
 @return DB_SUCCESS or error code. */
-static	MY_ATTRIBUTE((nonnull, warn_unused_result))
+static	__attribute__((nonnull, warn_unused_result))
 dberr_t
 row_import_cfg_read_index_fields(
 /*=============================*/
@@ -2655,7 +2642,7 @@ row_import_cfg_read_index_fields(
 Read the index names and root page numbers of the indexes and set the values.
 Row format [root_page_no, len of str, str ... ]
 @return DB_SUCCESS or error code. */
-static MY_ATTRIBUTE((nonnull, warn_unused_result))
+static __attribute__((nonnull, warn_unused_result))
 dberr_t
 row_import_read_index_data(
 /*=======================*/
@@ -2850,7 +2837,7 @@ row_import_read_indexes(
 /*********************************************************************//**
 Read the meta data (table columns) config file. Deserialise the contents of
 dict_col_t structure, along with the column name. */
-static	MY_ATTRIBUTE((nonnull, warn_unused_result))
+static	__attribute__((nonnull, warn_unused_result))
 dberr_t
 row_import_read_columns(
 /*====================*/
@@ -2975,7 +2962,7 @@ row_import_read_columns(
 /*****************************************************************//**
 Read the contents of the <tablespace>.cfg file.
 @return DB_SUCCESS or error code. */
-static	MY_ATTRIBUTE((nonnull, warn_unused_result))
+static	__attribute__((nonnull, warn_unused_result))
 dberr_t
 row_import_read_v1(
 /*===============*/
@@ -3141,7 +3128,7 @@ row_import_read_v1(
 /**
 Read the contents of the <tablespace>.cfg file.
 @return DB_SUCCESS or error code. */
-static	MY_ATTRIBUTE((nonnull, warn_unused_result))
+static	__attribute__((nonnull, warn_unused_result))
 dberr_t
 row_import_read_meta_data(
 /*======================*/
@@ -3184,7 +3171,7 @@ row_import_read_meta_data(
 /**
 Read the contents of the <tablename>.cfg file.
 @return DB_SUCCESS or error code. */
-static	MY_ATTRIBUTE((nonnull, warn_unused_result))
+static	__attribute__((nonnull, warn_unused_result))
 dberr_t
 row_import_read_cfg(
 /*================*/
@@ -3531,7 +3518,7 @@ row_import_for_mysql(
 
 	row_import	cfg;
 
-	memset(static_cast<void*>(&cfg), 0x0, sizeof(cfg));
+	memset(&cfg, 0x0, sizeof(cfg));
 
 	err = row_import_read_cfg(table, trx->mysql_thd, cfg);
 
