@@ -9,21 +9,13 @@ briefly in the InnoDB documentation. The contributions by Google are
 incorporated with their permission, and subject to the conditions contained in
 the file COPYING.Google.
 
-This program is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License, version 2.0,
-as published by the Free Software Foundation.
+This program is free software; you can redistribute it and/or modify it under
+the terms of the GNU General Public License as published by the Free Software
+Foundation; version 2 of the License.
 
-This program is also distributed with certain software (including
-but not limited to OpenSSL) that is licensed under separate terms,
-as designated in a particular file or component or in included license
-documentation.  The authors of MySQL hereby grant you an additional
-permission to link the program and your derivative works with the
-separately licensed software that they have included with MySQL.
-
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License, version 2.0, for more details.
+This program is distributed in the hope that it will be useful, but WITHOUT
+ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License along with
 this program; if not, write to the Free Software Foundation, Inc.,
@@ -303,21 +295,21 @@ sync_cell_get_event(
 	ulint type = cell->request_type;
 
 	if (type == SYNC_MUTEX) {
-		return(&((ib_mutex_t*) cell->wait_object)->event);
+		return(((ib_mutex_t*) cell->wait_object)->event);
 	} else if (type == SYNC_PRIO_MUTEX) {
-		return(&((ib_prio_mutex_t*) cell->wait_object)
+		return(((ib_prio_mutex_t*) cell->wait_object)
 		       ->high_priority_event);
 	} else if (type == RW_LOCK_WAIT_EX) {
-		return(&((rw_lock_t*) cell->wait_object)->wait_ex_event);
+		return(((rw_lock_t*) cell->wait_object)->wait_ex_event);
 	} else if (type == PRIO_RW_LOCK_SHARED) {
-		return(&((prio_rw_lock_t *) cell->wait_object)
+		return(((prio_rw_lock_t *) cell->wait_object)
 		       ->high_priority_s_event);
 	} else if (type == PRIO_RW_LOCK_EX) {
-		return(&((prio_rw_lock_t *) cell->wait_object)
+		return(((prio_rw_lock_t *) cell->wait_object)
 		       ->high_priority_x_event);
 	} else { /* RW_LOCK_SHARED and RW_LOCK_EX wait on the same event */
 		ut_ad(type == RW_LOCK_SHARED || type == RW_LOCK_EX);
-		return(&((rw_lock_t*) cell->wait_object)->event);
+		return(((rw_lock_t*) cell->wait_object)->event);
 	}
 }
 
