@@ -1,22 +1,14 @@
 /*****************************************************************************
 
-Copyright (c) 1996, 2016, Oracle and/or its affiliates. All Rights Reserved.
+Copyright (c) 1996, 2015, Oracle and/or its affiliates. All Rights Reserved.
 
-This program is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License, version 2.0,
-as published by the Free Software Foundation.
+This program is free software; you can redistribute it and/or modify it under
+the terms of the GNU General Public License as published by the Free Software
+Foundation; version 2 of the License.
 
-This program is also distributed with certain software (including
-but not limited to OpenSSL) that is licensed under separate terms,
-as designated in a particular file or component or in included license
-documentation.  The authors of MySQL hereby grant you an additional
-permission to link the program and your derivative works with the
-separately licensed software that they have included with MySQL.
-
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License, version 2.0, for more details.
+This program is distributed in the hope that it will be useful, but WITHOUT
+ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License along with
 this program; if not, write to the Free Software Foundation, Inc.,
@@ -1173,7 +1165,7 @@ trx_serialisation_number_get(
 /****************************************************************//**
 Assign the transaction its history serialisation number and write the
 update UNDO log record to the assigned rollback segment. */
-static MY_ATTRIBUTE((nonnull))
+static __attribute__((nonnull))
 void
 trx_write_serialisation_history(
 /*============================*/
@@ -1244,7 +1236,7 @@ trx_write_serialisation_history(
 
 /********************************************************************
 Finalize a transaction containing updates for a FTS table. */
-static MY_ATTRIBUTE((nonnull))
+static __attribute__((nonnull))
 void
 trx_finalize_for_fts_table(
 /*=======================*/
@@ -1277,7 +1269,7 @@ trx_finalize_for_fts_table(
 
 /******************************************************************//**
 Finalize a transaction containing updates to FTS tables. */
-static MY_ATTRIBUTE((nonnull))
+static __attribute__((nonnull))
 void
 trx_finalize_for_fts(
 /*=================*/
@@ -1351,7 +1343,7 @@ trx_flush_log_if_needed_low(
 /**********************************************************************//**
 If required, flushes the log to disk based on the value of
 innodb_flush_log_at_trx_commit. */
-static MY_ATTRIBUTE((nonnull))
+static __attribute__((nonnull))
 void
 trx_flush_log_if_needed(
 /*====================*/
@@ -1366,7 +1358,7 @@ trx_flush_log_if_needed(
 
 /****************************************************************//**
 Commits a transaction in memory. */
-static MY_ATTRIBUTE((nonnull))
+static __attribute__((nonnull))
 void
 trx_commit_in_memory(
 /*=================*/
@@ -1780,7 +1772,9 @@ trx_commit_or_rollback_prepare(
 			if (UNIV_UNLIKELY(trx->take_stats)) {
 				ut_usectime(&sec, &ms);
 				now = (ib_uint64_t)sec * 1000000 + ms;
-				trx->lock_que_wait_timer += now - trx->lock_que_wait_ustarted;
+				trx->lock_que_wait_timer
+					+= (ulint)
+					(now - trx->lock_que_wait_ustarted);
 			}
 
 			trx->lock.que_state = TRX_QUE_RUNNING;
@@ -2405,7 +2399,7 @@ which is in the prepared state
 @return	trx on match, the trx->xid will be invalidated;
 note that the trx may have been committed, unless the caller is
 holding lock_sys->mutex */
-static MY_ATTRIBUTE((nonnull, warn_unused_result))
+static __attribute__((nonnull, warn_unused_result))
 trx_t*
 trx_get_trx_by_xid_low(
 /*===================*/
@@ -2436,8 +2430,7 @@ trx_get_trx_by_xid_low(
 
 			/* Invalidate the XID, so that subsequent calls
 			will not find it. */
-			memset(static_cast<void*>(&trx->xid), 0,
-			       sizeof(trx->xid));
+			memset(&trx->xid, 0, sizeof(trx->xid));
 			trx->xid.formatID = -1;
 			break;
 		}
