@@ -28,26 +28,13 @@ Copyright (c) 2006, 2015, Percona and/or its affiliates. All rights reserved.
 
 #define TOKU_METADB_NAME "tokudb_meta"
 
-#if defined(HAVE_PSI_MUTEX_INTERFACE)
-static pfs_key_t tokudb_map_mutex_key;
-
-static PSI_mutex_info all_tokudb_mutexes[] = {
-    {&tokudb_map_mutex_key, "tokudb_map_mutex", 0},
-    {&ha_tokudb_mutex_key, "ha_tokudb_mutex", 0},
-};
-
-static PSI_rwlock_info all_tokudb_rwlocks[] = {
-    {&num_DBs_lock_key, "num_DBs_lock", 0},
-};
-#endif /* HAVE_PSI_MUTEX_INTERFACE */
-
 typedef struct savepoint_info {
     DB_TXN* txn;
     tokudb_trx_data* trx;
     bool in_sub_stmt;
 } *SP_INFO, SP_INFO_T;
 
-#if defined(TOKU_INCLUDE_OPTION_STRUCTS) && TOKU_INCLUDE_OPTION_STRUCTS
+#if TOKU_INCLUDE_OPTION_STRUCTS
 ha_create_table_option tokudb_table_options[] = {
     HA_TOPTION_SYSVAR("compression", row_format, row_format),
     HA_TOPTION_END
@@ -57,7 +44,7 @@ ha_create_table_option tokudb_index_options[] = {
     HA_IOPTION_BOOL("clustering", clustering, 0),
     HA_IOPTION_END
 };
-#endif  // defined(TOKU_INCLUDE_OPTION_STRUCTS) && TOKU_INCLUDE_OPTION_STRUCTS
+#endif
 
 static handler* tokudb_create_handler(
     handlerton* hton,
@@ -76,21 +63,18 @@ static bool tokudb_show_status(
     THD* thd,
     stat_print_fn* print,
     enum ha_stat_type);
-#if defined(TOKU_INCLUDE_HANDLERTON_HANDLE_FATAL_SIGNAL) && \
-    TOKU_INCLUDE_HANDLERTON_HANDLE_FATAL_SIGNAL
+#if TOKU_INCLUDE_HANDLERTON_HANDLE_FATAL_SIGNAL
 static void tokudb_handle_fatal_signal(handlerton* hton, THD* thd, int sig);
-#endif  // defined(TOKU_INCLUDE_HANDLERTON_HANDLE_FATAL_SIGNAL) &&
-        // TOKU_INCLUDE_HANDLERTON_HANDLE_FATAL_SIGNAL
+#endif
 static int tokudb_close_connection(handlerton* hton, THD* thd);
-static void tokudb_kill_connection(handlerton *hton, THD *thd);
 static int tokudb_commit(handlerton* hton, THD* thd, bool all);
 static int tokudb_rollback(handlerton* hton, THD* thd, bool all);
-#if defined(TOKU_INCLUDE_XA) && TOKU_INCLUDE_XA
+#if TOKU_INCLUDE_XA
 static int tokudb_xa_prepare(handlerton* hton, THD* thd, bool all);
 static int tokudb_xa_recover(handlerton* hton, XID* xid_list, uint len);
 static int tokudb_commit_by_xid(handlerton* hton, XID* xid);
 static int tokudb_rollback_by_xid(handlerton* hton, XID* xid);
-#endif  // defined(TOKU_INCLUDE_XA) && TOKU_INCLUDE_XA
+#endif
 
 static int tokudb_rollback_to_savepoint(
     handlerton* hton,
@@ -108,7 +92,6 @@ static int tokudb_discover_table_existence(
     const char* db,
     const char* name);
 #endif
-#if defined(TOKU_INCLUDE_DISCOVER_FRM) && TOKU_INCLUDE_DISCOVER_FRM
 static int tokudb_discover(
     handlerton* hton,
     THD* thd,
@@ -132,13 +115,12 @@ static int tokudb_discover3(
     char* path,
     uchar** frmblob,
     size_t* frmlen);
-#endif  // defined(TOKU_INCLUDE_DISCOVER_FRM) && TOKU_INCLUDE_DISCOVER_FRM
 handlerton* tokudb_hton;
 
 const char* ha_tokudb_ext = ".tokudb";
 DB_ENV* db_env;
 
-#if defined(TOKU_THDVAR_MEMALLOC_BUG) && TOKU_THDVAR_MEMALLOC_BUG
+#if TOKU_THDVAR_MEMALLOC_BUG
 static tokudb::thread::mutex_t tokudb_map_mutex;
 static TREE tokudb_map;
 struct tokudb_map_pair {
@@ -149,7 +131,7 @@ struct tokudb_map_pair {
 static int tokudb_map_pair_cmp(void *custom_arg, const void *a, const void *b) {
 #else
 static int tokudb_map_pair_cmp(
-    TOKUDB_UNUSED(const void* custom_arg),
+    const void* custom_arg,
     const void* a,
     const void* b) {
 #endif
@@ -163,7 +145,7 @@ static int tokudb_map_pair_cmp(
     else
         return 0;
 };
-#endif  // defined(TOKU_THDVAR_MEMALLOC_BUG) && TOKU_THDVAR_MEMALLOC_BUG
+#endif
 
 static PARTITIONED_COUNTER tokudb_primary_key_bytes_inserted;
 void toku_hton_update_primary_key_bytes_inserted(uint64_t row_size) {
@@ -236,10 +218,6 @@ extern "C" {
 // use constructor and destructor functions to create and destroy
 // the lock before and after main(), respectively.
 int tokudb_hton_initialized;
-
-// tokudb_hton_initialized_lock can not be instrumented as it must be
-// initialized before mysql_mutex_register() call to protect
-// some globals from race condition.
 tokudb::thread::rwlock_t tokudb_hton_initialized_lock;
 
 static SHOW_VAR *toku_global_status_variables = NULL;
@@ -295,24 +273,12 @@ static int tokudb_init_func(void *p) {
     int r;
 
     // 3938: lock the handlerton's initialized status flag for writing
-    rwlock_t_lock_write(tokudb_hton_initialized_lock);
-
-#ifdef HAVE_PSI_INTERFACE
-    /* Register TokuDB mutex keys with MySQL performance schema */
-    int count;
-
-    count = array_elements(all_tokudb_mutexes);
-    mysql_mutex_register("tokudb", all_tokudb_mutexes, count);
-
-    count = array_elements(all_tokudb_rwlocks);
-    mysql_rwlock_register("tokudb", all_tokudb_rwlocks, count);
-
-    tokudb_map_mutex.reinit(tokudb_map_mutex_key);
-#endif /* HAVE_PSI_INTERFACE */
+    tokudb_hton_initialized_lock.lock_write();
 
     db_env = NULL;
-    tokudb_hton = (handlerton*)p;
+    tokudb_hton = (handlerton *) p;
 
+#if TOKUDB_CHECK_JEMALLOC
     if (tokudb::sysvars::check_jemalloc) {
         typedef int (*mallctl_type)(
             const char*,
@@ -339,6 +305,7 @@ static int tokudb_init_func(void *p) {
             goto error;
         }
     }
+#endif
 
     r = tokudb_set_product_name();
     if (r) {
@@ -378,7 +345,6 @@ static int tokudb_init_func(void *p) {
 
     tokudb_hton->create = tokudb_create_handler;
     tokudb_hton->close_connection = tokudb_close_connection;
-    tokudb_hton->kill_connection = tokudb_kill_connection;
 
     tokudb_hton->savepoint_offset = sizeof(SP_INFO_T);
     tokudb_hton->savepoint_set = tokudb_savepoint;
@@ -389,35 +355,31 @@ static int tokudb_init_func(void *p) {
     tokudb_hton->discover_table = tokudb_discover_table;
     tokudb_hton->discover_table_existence = tokudb_discover_table_existence;
 #else
-#if defined(TOKU_INCLUDE_DISCOVER_FRM) && TOKU_INCLUDE_DISCOVER_FRM
     tokudb_hton->discover = tokudb_discover;
 #if defined(MYSQL_HANDLERTON_INCLUDE_DISCOVER2)
     tokudb_hton->discover2 = tokudb_discover2;
-#endif  // MYSQL_HANDLERTON_INCLUDE_DISCOVER2
-#endif  // defined(TOKU_INCLUDE_DISCOVER_FRM) && TOKU_INCLUDE_DISCOVER_FRM
-#endif  // 100000 <= MYSQL_VERSION_ID && MYSQL_VERSION_ID <= 100099
+#endif
+#endif
     tokudb_hton->commit = tokudb_commit;
     tokudb_hton->rollback = tokudb_rollback;
-#if defined(TOKU_INCLUDE_XA) && TOKU_INCLUDE_XA
+#if TOKU_INCLUDE_XA
     tokudb_hton->prepare = tokudb_xa_prepare;
     tokudb_hton->recover = tokudb_xa_recover;
     tokudb_hton->commit_by_xid = tokudb_commit_by_xid;
     tokudb_hton->rollback_by_xid = tokudb_rollback_by_xid;
-#endif  // defined(TOKU_INCLUDE_XA) && TOKU_INCLUDE_XA
+#endif
 
     tokudb_hton->panic = tokudb_end;
     tokudb_hton->flush_logs = tokudb_flush_logs;
     tokudb_hton->show_status = tokudb_show_status;
-#if defined(TOKU_INCLUDE_HANDLERTON_HANDLE_FATAL_SIGNAL) && \
-    TOKU_INCLUDE_HANDLERTON_HANDLE_FATAL_SIGNAL
+#if TOKU_INCLUDE_HANDLERTON_HANDLE_FATAL_SIGNAL
     tokudb_hton->handle_fatal_signal = tokudb_handle_fatal_signal;
-#endif  // defined(TOKU_INCLUDE_HANDLERTON_HANDLE_FATAL_SIGNAL) &&
-        // TOKU_INCLUDE_HANDLERTON_HANDLE_FATAL_SIGNAL
+#endif
 
-#if defined(TOKU_INCLUDE_OPTION_STRUCTS) && TOKU_INCLUDE_OPTION_STRUCTS
+#if TOKU_INCLUDE_OPTION_STRUCTS
     tokudb_hton->table_options = tokudb_table_options;
     tokudb_hton->index_options = tokudb_index_options;
-#endif  // defined(TOKU_INCLUDE_OPTION_STRUCTS) && TOKU_INCLUDE_OPTION_STRUCTS
+#endif
 
     if (!tokudb_home)
         tokudb_home = mysql_real_data_home;
@@ -444,16 +406,6 @@ static int tokudb_init_func(void *p) {
     db_env->set_errcall(db_env, tokudb_print_error);
     db_env->set_errpfx(db_env, tokudb_hton_name);
 
-    // Handle deprecated options
-    if (tokudb::sysvars::pk_insert_mode(NULL) != 1) {
-        TOKUDB_TRACE("Using tokudb_pk_insert_mode is deprecated and the "
-            "parameter may be removed in future releases. "
-            "tokudb_pk_insert_mode=0 is now forbidden. "
-            "See documentation and release notes for details");
-        if (tokudb::sysvars::pk_insert_mode(NULL) < 1)
-           tokudb::sysvars::set_pk_insert_mode(NULL, 1);
-    }
-
     //
     // set default comparison functions
     //
@@ -583,14 +535,11 @@ static int tokudb_init_func(void *p) {
     db_env->change_fsync_log_period(db_env, tokudb::sysvars::fsync_log_period);
 
     db_env->set_lock_timeout_callback(db_env, tokudb_lock_timeout_callback);
-    db_env->set_dir_per_db(db_env, tokudb::sysvars::dir_per_db);
 
     db_env->set_loader_memory_size(
         db_env,
         tokudb_get_loader_memory_size_callback);
 
-    db_env->set_check_thp(db_env, tokudb::sysvars::check_jemalloc);
-
     r = db_env->open(
         db_env,
         tokudb_home,
@@ -657,9 +606,9 @@ static int tokudb_init_func(void *p) {
 
     tokudb_primary_key_bytes_inserted = create_partitioned_counter();
 
-#if defined(TOKU_THDVAR_MEMALLOC_BUG) && TOKU_THDVAR_MEMALLOC_BUG
+#if TOKU_THDVAR_MEMALLOC_BUG
     init_tree(&tokudb_map, 0, 0, 0, tokudb_map_pair_cmp, true, NULL, NULL);
-#endif  // defined(TOKU_THDVAR_MEMALLOC_BUG) && TOKU_THDVAR_MEMALLOC_BUG
+#endif
 
     if (tokudb::sysvars::strip_frm_data) {
         r = tokudb::metadata::strip_frm_data(db_env);
@@ -688,7 +637,7 @@ error:
     DBUG_RETURN(true);
 }
 
-static int tokudb_done_func(TOKUDB_UNUSED(void* p)) {
+static int tokudb_done_func(void* p) {
     TOKUDB_DBUG_ENTER("");
     tokudb::memory::free(toku_global_status_variables);
     toku_global_status_variables = NULL;
@@ -704,8 +653,7 @@ static handler* tokudb_create_handler(
     return new(mem_root) ha_tokudb(hton, table);
 }
 
-int tokudb_end(TOKUDB_UNUSED(handlerton* hton),
-               TOKUDB_UNUSED(ha_panic_function type)) {
+int tokudb_end(handlerton* hton, ha_panic_function type) {
     TOKUDB_DBUG_ENTER("");
     int error = 0;
     
@@ -713,7 +661,7 @@ int tokudb_end(TOKUDB_UNUSED(handlerton* hton),
     // initialized. grab a writer lock for the duration of the
     // call, so we can drop the flag and destroy the mutexes
     // in isolation.
-    rwlock_t_lock_write(tokudb_hton_initialized_lock);
+    tokudb_hton_initialized_lock.lock_write();
     assert_always(tokudb_hton_initialized);
 
     tokudb::background::destroy();
@@ -725,7 +673,7 @@ int tokudb_end(TOKUDB_UNUSED(handlerton* hton),
 
         // count the total number of prepared txn's that we discard
         long total_prepared = 0;
-#if defined(TOKU_INCLUDE_XA) && TOKU_INCLUDE_XA
+#if TOKU_INCLUDE_XA
         TOKUDB_TRACE_FOR_FLAGS(TOKUDB_DEBUG_XA, "begin XA cleanup");
         while (1) {
             // get xid's 
@@ -752,11 +700,11 @@ int tokudb_end(TOKUDB_UNUSED(handlerton* hton),
             total_prepared += n_prepared;
         }
         TOKUDB_TRACE_FOR_FLAGS(TOKUDB_DEBUG_XA, "end XA cleanup");
-#endif  // defined(TOKU_INCLUDE_XA) && TOKU_INCLUDE_XA
+#endif
         error = db_env->close(
             db_env,
             total_prepared > 0 ? TOKUFT_DIRTY_SHUTDOWN : 0);
-#if defined(TOKU_INCLUDE_XA) && TOKU_INCLUDE_XA
+#if TOKU_INCLUDE_XA
         if (error != 0 && total_prepared > 0) {
             sql_print_error(
                 "%s: %ld prepared txns still live, please shutdown, error %d",
@@ -764,7 +712,7 @@ int tokudb_end(TOKUDB_UNUSED(handlerton* hton),
                 total_prepared,
                 error);
         } else
-#endif  // defined(TOKU_INCLUDE_XA) && TOKU_INCLUDE_XA
+#endif
         assert_always(error == 0);
         db_env = NULL;
     }
@@ -774,9 +722,9 @@ int tokudb_end(TOKUDB_UNUSED(handlerton* hton),
         tokudb_primary_key_bytes_inserted = NULL;
     }
 
-#if defined(TOKU_THDVAR_MEMALLOC_BUG) && TOKU_THDVAR_MEMALLOC_BUG
+#if TOKU_THDVAR_MEMALLOC_BUG
     delete_tree(&tokudb_map);
-#endif  // defined(TOKU_THDVAR_MEMALLOC_BUG) && TOKU_THDVAR_MEMALLOC_BUG
+#endif
 
     // 3938: drop the initialized flag and unlock
     tokudb_hton_initialized = 0;
@@ -785,35 +733,29 @@ int tokudb_end(TOKUDB_UNUSED(handlerton* hton),
     TOKUDB_DBUG_RETURN(error);
 }
 
-static int tokudb_close_connection(TOKUDB_UNUSED(handlerton* hton), THD* thd) {
+static int tokudb_close_connection(handlerton* hton, THD* thd) {
     int error = 0;
     tokudb_trx_data* trx = (tokudb_trx_data*)thd_get_ha_data(thd, tokudb_hton);
     if (trx && trx->checkpoint_lock_taken) {
         error = db_env->checkpointing_resume(db_env);
     }
     tokudb::memory::free(trx);
-#if defined(TOKU_THDVAR_MEMALLOC_BUG) && TOKU_THDVAR_MEMALLOC_BUG
-    mutex_t_lock(tokudb_map_mutex);
-    struct tokudb_map_pair key = {thd, NULL};
+#if TOKU_THDVAR_MEMALLOC_BUG
+    tokudb_map_mutex.lock();
+    struct tokudb_map_pair key = { thd, NULL };
     struct tokudb_map_pair* found_key =
-        (struct tokudb_map_pair*)tree_search(&tokudb_map, &key, NULL);
+        (struct tokudb_map_pair*) tree_search(&tokudb_map, &key, NULL);
 
     if (found_key) {
         tokudb::memory::free(found_key->last_lock_timeout);
         tree_delete(&tokudb_map, found_key, sizeof(*found_key), NULL);
     }
-    mutex_t_unlock(tokudb_map_mutex);
-#endif  // defined(TOKU_THDVAR_MEMALLOC_BUG) && TOKU_THDVAR_MEMALLOC_BUG
+    tokudb_map_mutex.unlock();
+#endif
     return error;
 }
 
-void tokudb_kill_connection(TOKUDB_UNUSED(handlerton* hton), THD* thd) {
-    TOKUDB_DBUG_ENTER("");
-    db_env->kill_waiter(db_env, thd);
-    DBUG_VOID_RETURN;
-}
-
-bool tokudb_flush_logs(TOKUDB_UNUSED(handlerton* hton)) {
+bool tokudb_flush_logs(handlerton * hton) {
     TOKUDB_DBUG_ENTER("");
     int error;
     bool result = 0;
@@ -905,7 +847,7 @@ extern "C" enum durability_properties thd_get_durability_property(
 #endif
 
 // Determine if an fsync is used when a transaction is committed.  
-static bool tokudb_sync_on_commit(THD* thd) {
+static bool tokudb_sync_on_commit(THD* thd, tokudb_trx_data* trx, DB_TXN* txn) {
 #if MYSQL_VERSION_ID >= 50600
     // Check the client durability property which is set during 2PC
     if (thd_get_durability_property(thd) == HA_IGNORE_DURABILITY)
@@ -928,7 +870,8 @@ static int tokudb_commit(handlerton * hton, THD * thd, bool all) {
     DB_TXN **txn = all ? &trx->all : &trx->stmt;
     DB_TXN *this_txn = *txn;
     if (this_txn) {
-        uint32_t syncflag = tokudb_sync_on_commit(thd) ? 0 : DB_TXN_NOSYNC;
+        uint32_t syncflag =
+            tokudb_sync_on_commit(thd, trx, this_txn) ? 0 : DB_TXN_NOSYNC;
         TOKUDB_TRACE_FOR_FLAGS(
             TOKUDB_DEBUG_TXN,
             "commit trx %u txn %p syncflag %u",
@@ -979,7 +922,7 @@ static int tokudb_rollback(handlerton * hton, THD * thd, bool all) {
     TOKUDB_DBUG_RETURN(0);
 }
 
-#if defined(TOKU_INCLUDE_XA) && TOKU_INCLUDE_XA
+#if TOKU_INCLUDE_XA
 static bool tokudb_sync_on_prepare(void) {
     TOKUDB_TRACE_FOR_FLAGS(TOKUDB_DEBUG_XA, "enter");
     // skip sync of log if fsync log period > 0
@@ -993,7 +936,7 @@ static bool tokudb_sync_on_prepare(void) {
 }   
 
 static int tokudb_xa_prepare(handlerton* hton, THD* thd, bool all) {
-    TOKUDB_DBUG_ENTER("%u", all);
+    TOKUDB_DBUG_ENTER("");
     TOKUDB_TRACE_FOR_FLAGS(TOKUDB_DEBUG_XA, "enter");
     int r = 0;
 
@@ -1021,22 +964,6 @@ static int tokudb_xa_prepare(handlerton* hton, THD* thd, bool all) {
         r = txn->xa_prepare(txn, &thd_xid, syncflag);
         // test hook to induce a crash on a debug build
         DBUG_EXECUTE_IF("tokudb_crash_prepare_after", DBUG_SUICIDE(););
-
-        // XA log entries can be interleaved in the binlog since XA prepare on the master
-        // flushes to the binlog.  There can be log entries from different clients pushed
-        // into the binlog before XA commit is executed on the master.  Therefore, the slave
-        // thread must be able to juggle multiple XA transactions.  Tokudb does this by
-        // zapping the client transaction context on the slave when executing the XA prepare
-        // and expecting to process XA commit with commit_by_xid (which supplies the XID so
-        // that the transaction can be looked up and committed).
-        if (r == 0 && all && thd->slave_thread) {
-            TOKUDB_TRACE_FOR_FLAGS(TOKUDB_DEBUG_XA, "zap txn context %u", thd_sql_command(thd));
-            if (thd_sql_command(thd) == SQLCOM_XA_PREPARE) {
-                trx->all = NULL;
-                trx->sub_sp_level = NULL;
-                trx->sp_level = NULL;
-            }
-        }
     } else {
         TOKUDB_TRACE_FOR_FLAGS(TOKUDB_DEBUG_XA, "nothing to prepare %d", all);
     }
@@ -1044,9 +971,7 @@ static int tokudb_xa_prepare(handlerton* hton, THD* thd, bool all) {
     TOKUDB_DBUG_RETURN(r);
 }
 
-static int tokudb_xa_recover(TOKUDB_UNUSED(handlerton* hton),
-                             XID* xid_list,
-                             uint len) {
+static int tokudb_xa_recover(handlerton* hton, XID* xid_list, uint len) {
     TOKUDB_DBUG_ENTER("");
     TOKUDB_TRACE_FOR_FLAGS(TOKUDB_DEBUG_XA, "enter");
     int r = 0;
@@ -1066,10 +991,9 @@ static int tokudb_xa_recover(TOKUDB_UNUSED(handlerton* hton),
     TOKUDB_DBUG_RETURN((int)num_returned);
 }
 
-static int tokudb_commit_by_xid(TOKUDB_UNUSED(handlerton* hton), XID* xid) {
+static int tokudb_commit_by_xid(handlerton* hton, XID* xid) {
     TOKUDB_DBUG_ENTER("");
     TOKUDB_TRACE_FOR_FLAGS(TOKUDB_DEBUG_XA, "enter");
-    TOKUDB_TRACE_FOR_FLAGS(TOKUDB_DEBUG_XA, "xid %p", xid);
     int r = 0;
     DB_TXN* txn = NULL;
     TOKU_XA_XID* toku_xid = (TOKU_XA_XID*)xid;
@@ -1086,10 +1010,9 @@ cleanup:
     TOKUDB_DBUG_RETURN(r);
 }
 
-static int tokudb_rollback_by_xid(TOKUDB_UNUSED(handlerton* hton), XID* xid) {
+static int tokudb_rollback_by_xid(handlerton* hton, XID*  xid) {
     TOKUDB_DBUG_ENTER("");
     TOKUDB_TRACE_FOR_FLAGS(TOKUDB_DEBUG_XA, "enter");
-    TOKUDB_TRACE_FOR_FLAGS(TOKUDB_DEBUG_XA, "xid %p", xid);
     int r = 0;
     DB_TXN* txn = NULL;
     TOKU_XA_XID* toku_xid = (TOKU_XA_XID*)xid;
@@ -1106,7 +1029,7 @@ cleanup:
     TOKUDB_DBUG_RETURN(r);
 }
 
-#endif  // defined(TOKU_INCLUDE_XA) && TOKU_INCLUDE_XA
+#endif
 
 static int tokudb_savepoint(handlerton * hton, THD * thd, void *savepoint) {
     TOKUDB_DBUG_ENTER("%p", savepoint);
@@ -1233,9 +1156,8 @@ static int tokudb_discover_table_existence(
     my_free(frmblob);
     return res != ENOENT;
 }
-#endif // 100000 <= MYSQL_VERSION_ID && MYSQL_VERSION_ID <= 100099
+#endif
 
-#if defined(TOKU_INCLUDE_DISCOVER_FRM) && TOKU_INCLUDE_DISCOVER_FRM
 static int tokudb_discover(
     handlerton* hton,
     THD* thd,
@@ -1267,13 +1189,15 @@ static int tokudb_discover2(
     return tokudb_discover3(hton, thd, db, name, path, frmblob, frmlen);
 }
 
-static int tokudb_discover3(TOKUDB_UNUSED(handlerton* hton),
-                            THD* thd,
-                            const char* db,
-                            const char* name,
-                            char* path,
-                            uchar** frmblob,
-                            size_t* frmlen) {
+static int tokudb_discover3(
+    handlerton* hton,
+    THD* thd,
+    const char* db,
+    const char* name,
+    char* path,
+    uchar** frmblob,
+    size_t* frmlen) {
+
     TOKUDB_DBUG_ENTER("%s %s %s", db, name, path);
     int error;
     DB* status_db = NULL;
@@ -1331,7 +1255,6 @@ cleanup:
     }
     TOKUDB_DBUG_RETURN(error);
 }
-#endif  // defined(TOKU_INCLUDE_DISCOVER_FRM) && TOKU_INCLUDE_DISCOVER_FRM
 
 
 #define STATPRINT(legend, val) if (legend != NULL && val != NULL) \
@@ -1537,7 +1460,7 @@ cleanup:
 }
 
 static bool tokudb_show_status(
-    TOKUDB_UNUSED(handlerton* hton),
+    handlerton* hton,
     THD* thd,
     stat_print_fn* stat_print,
     enum ha_stat_type stat_type) {
@@ -1552,8 +1475,7 @@ static bool tokudb_show_status(
     return false;
 }
 
-#if defined(TOKU_INCLUDE_HANDLERTON_HANDLE_FATAL_SIGNAL) && \
-    TOKU_INCLUDE_HANDLERTON_HANDLE_FATAL_SIGNAL
+#if TOKU_INCLUDE_HANDLERTON_HANDLE_FATAL_SIGNAL
 static void tokudb_handle_fatal_signal(
     TOKUDB_UNUSED(handlerton* hton),
     TOKUDB_UNUSD(THD* thd),
@@ -1563,12 +1485,12 @@ static void tokudb_handle_fatal_signal(
         db_env_try_gdb_stack_trace(tokudb_gdb_path);
     }
 }
-#endif  // defined(TOKU_INCLUDE_HANDLERTON_HANDLE_FATAL_SIGNAL) &&
-        // TOKU_INCLUDE_HANDLERTON_HANDLE_FATAL_SIGNAL
+#endif
 
-static void tokudb_print_error(TOKUDB_UNUSED(const DB_ENV* db_env),
-                               const char* db_errpfx,
-                               const char* buffer) {
+static void tokudb_print_error(
+    const DB_ENV* db_env,
+    const char* db_errpfx,
+    const char* buffer) {
     sql_print_error("%s: %s", db_errpfx, buffer);
 }
 
@@ -1635,8 +1557,7 @@ struct st_mysql_storage_engine tokudb_storage_engine = {
     MYSQL_HANDLERTON_INTERFACE_VERSION
 };
 
-#if defined(TOKU_INCLUDE_LOCK_TIMEOUT_QUERY_STRING) && \
-    TOKU_INCLUDE_LOCK_TIMEOUT_QUERY_STRING
+#if TOKU_INCLUDE_LOCK_TIMEOUT_QUERY_STRING
 struct tokudb_search_txn_extra {
     bool match_found;
     uint64_t match_txn_id;
@@ -1677,10 +1598,10 @@ static bool tokudb_txn_id_to_client_id(
     }
     return e.match_found;
 }
-#endif  // defined(TOKU_INCLUDE_LOCK_TIMEOUT_QUERY_STRING) &&
-        // TOKU_INCLUDE_LOCK_TIMEOUT_QUERY_STRING
+#endif
 
 static void tokudb_pretty_key(
+    const DB* db,
     const DBT* key,
     const char* default_key,
     String* out) {
@@ -1702,12 +1623,12 @@ static void tokudb_pretty_key(
     }
 }
 
-void tokudb_pretty_left_key(const DBT* key, String* out) {
-    tokudb_pretty_key(key, "-infinity", out);
+void tokudb_pretty_left_key(const DB* db, const DBT* key, String* out) {
+    tokudb_pretty_key(db, key, "-infinity", out);
 }
 
-void tokudb_pretty_right_key(const DBT* key, String* out) {
-    tokudb_pretty_key(key, "+infinity", out);
+void tokudb_pretty_right_key(const DB* db, const DBT* key, String* out) {
+    tokudb_pretty_key(db, key, "+infinity", out);
 }
 
 const char* tokudb_get_index_name(DB* db) {
@@ -1754,20 +1675,20 @@ static void tokudb_lock_timeout_callback(
         log_str.append_ulonglong(blocking_txnid);
         if (tokudb_equal_key(left_key, right_key)) {
             String key_str;
-            tokudb_pretty_key(left_key, "?", &key_str);
+            tokudb_pretty_key(db, left_key, "?", &key_str);
             log_str.append(", \"key\":");
             log_str.append("\"");
             log_str.append(key_str);
             log_str.append("\"");
         } else {
             String left_str;
-            tokudb_pretty_left_key(left_key, &left_str);
+            tokudb_pretty_left_key(db, left_key, &left_str);
             log_str.append(", \"key_left\":");
             log_str.append("\"");
             log_str.append(left_str);
             log_str.append("\"");
             String right_str;
-            tokudb_pretty_right_key(right_key, &right_str);
+            tokudb_pretty_right_key(db, right_key, &right_str);
             log_str.append(", \"key_right\":");
             log_str.append("\"");
             log_str.append(right_str);
@@ -1780,14 +1701,14 @@ static void tokudb_lock_timeout_callback(
             char* new_lock_timeout =
                 tokudb::memory::strdup(log_str.c_ptr(), MY_FAE);
             tokudb::sysvars::set_last_lock_timeout(thd, new_lock_timeout);
-#if defined(TOKU_THDVAR_MEMALLOC_BUG) && TOKU_THDVAR_MEMALLOC_BUG
-            mutex_t_lock(tokudb_map_mutex);
-            struct tokudb_map_pair old_key = {thd, old_lock_timeout};
+#if TOKU_THDVAR_MEMALLOC_BUG
+            tokudb_map_mutex.lock();
+            struct tokudb_map_pair old_key = { thd, old_lock_timeout };
             tree_delete(&tokudb_map, &old_key, sizeof old_key, NULL);
-            struct tokudb_map_pair new_key = {thd, new_lock_timeout};
+            struct tokudb_map_pair new_key = { thd, new_lock_timeout };
             tree_insert(&tokudb_map, &new_key, sizeof new_key, NULL);
-            mutex_t_unlock(tokudb_map_mutex);
-#endif  // defined(TOKU_THDVAR_MEMALLOC_BUG) && TOKU_THDVAR_MEMALLOC_BUG
+            tokudb_map_mutex.unlock();
+#endif
             tokudb::memory::free(old_lock_timeout);
         }
         // dump to stderr
@@ -1803,8 +1724,7 @@ static void tokudb_lock_timeout_callback(
                 mysql_thread_id,
                 (int)qs->length,
                 qs->str);
-#if defined(TOKU_INCLUDE_LOCK_TIMEOUT_QUERY_STRING) && \
-    TOKU_INCLUDE_LOCK_TIMEOUT_QUERY_STRING
+#if TOKU_INCLUDE_LOCK_TIMEOUT_QUERY_STRING
             uint64_t blocking_thread_id = 0;
             if (tokudb_txn_id_to_client_id(
                     thd,
@@ -1824,8 +1744,7 @@ static void tokudb_lock_timeout_callback(
                         blocking_qs.c_ptr());
                 }
             }
-#endif  // defined(TOKU_INCLUDE_LOCK_TIMEOUT_QUERY_STRING) &&
-        // TOKU_INCLUDE_LOCK_TIMEOUT_QUERY_STRING
+#endif
         }
     }
 }
@@ -1833,9 +1752,7 @@ static void tokudb_lock_timeout_callback(
 // Retrieves variables for information_schema.global_status.
 // Names (columnname) are automatically converted to upper case,
 // and prefixed with "TOKUDB_"
-static int show_tokudb_vars(TOKUDB_UNUSED(THD* thd),
-                            SHOW_VAR* var,
-                            TOKUDB_UNUSED(char* buff)) {
+static int show_tokudb_vars(THD *thd, SHOW_VAR *var, char *buff) {
     TOKUDB_DBUG_ENTER("");
 
     int error;
@@ -1939,6 +1856,16 @@ static SHOW_VAR toku_global_status_variables_export[]= {
     {NullS, NullS, SHOW_LONG}
 };
 
+#if TOKU_INCLUDE_BACKTRACE
+#include <execinfo.h>
+static void tokudb_backtrace(void) {
+    const int N_POINTERS = 30;
+    void *backtrace_pointers[N_POINTERS];
+    int n = backtrace(backtrace_pointers, N_POINTERS);
+    backtrace_symbols_fd(backtrace_pointers, n, fileno(stderr));
+}
+#endif
+
 #ifdef MARIA_PLUGIN_INTERFACE_VERSION
 maria_declare_plugin(tokudb) 
 #else
