@@ -81,22 +81,21 @@ extern uint         read_status_frequency;
 extern my_bool      strip_frm_data;
 extern char*        tmp_dir;
 extern uint         write_status_frequency;
-extern my_bool      dir_per_db;
 extern char*        version;
 
-#if defined(TOKU_INCLUDE_HANDLERTON_HANDLE_FATAL_SIGNAL) && \
-    TOKU_INCLUDE_HANDLERTON_HANDLE_FATAL_SIGNAL
+#if TOKU_INCLUDE_HANDLERTON_HANDLE_FATAL_SIGNAL
 extern char*        gdb_path;
 extern my_bool      gdb_on_fatal;
-#endif  // defined(TOKU_INCLUDE_HANDLERTON_HANDLE_FATAL_SIGNAL) &&
-        // TOKU_INCLUDE_HANDLERTON_HANDLE_FATAL_SIGNAL
+#endif
 
-extern my_bool         check_jemalloc;
+#if TOKUDB_CHECK_JEMALLOC
+extern uint         check_jemalloc;
+#endif
 
-#if defined(TOKUDB_DEBUG)
+#if TOKUDB_DEBUG
 // used to control background job manager
 extern my_bool      debug_pause_background_job_manager;
-#endif // defined(TOKUDB_DEBUG)
+#endif // TOKUDB_DEBUG
 
 // session/thread
 my_bool     alter_print_error(THD* thd);
@@ -113,8 +112,8 @@ my_bool     create_index_online(THD* thd);
 my_bool     disable_hot_alter(THD* thd);
 my_bool     disable_prefetching(THD* thd);
 my_bool     disable_slow_alter(THD* thd);
-my_bool     enable_fast_update(THD* thd);
-my_bool     enable_fast_upsert(THD* thd);
+my_bool     disable_slow_update(THD* thd);
+my_bool     disable_slow_upsert(THD* thd);
 empty_scan_mode_t empty_scan(THD* thd);
 uint        fanout(THD* thd);
 my_bool     hide_default_row_format(THD* thd);
@@ -129,18 +128,15 @@ double      optimize_index_fraction(THD* thd);
 const char* optimize_index_name(THD* thd);
 ulonglong   optimize_throttle(THD* thd);
 uint        pk_insert_mode(THD* thd);
-void        set_pk_insert_mode(THD* thd, uint mode);
 my_bool     prelock_empty(THD* thd);
 uint        read_block_size(THD* thd);
 uint        read_buf_size(THD* thd);
 row_format_t row_format(THD *thd);
-#if defined(TOKU_INCLUDE_RFR) && TOKU_INCLUDE_RFR
 my_bool     rpl_check_readonly(THD* thd);
 my_bool     rpl_lookup_rows(THD* thd);
 ulonglong   rpl_lookup_rows_delay(THD* thd);
 my_bool     rpl_unique_checks(THD* thd);
 ulonglong   rpl_unique_checks_delay(THD* thd);
-#endif // defined(TOKU_INCLUDE_RFR) && TOKU_INCLUDE_RFR
 my_bool     support_xa(THD* thd);
 
 extern st_mysql_sys_var* system_variables[];
